/****************************************************************************
** Meta object code from reading C++ file 'application.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/pcmanfm-qt-0.11.1/pcmanfm/application.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'application.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_PCManFM__ProxyStyle_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PCManFM__ProxyStyle_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PCManFM__ProxyStyle_t qt_meta_stringdata_PCManFM__ProxyStyle = {
    {
QT_MOC_LITERAL(0, 0, 19) // "PCManFM::ProxyStyle"

    },
    "PCManFM::ProxyStyle"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PCManFM__ProxyStyle[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void PCManFM::ProxyStyle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject PCManFM::ProxyStyle::staticMetaObject = {
    { &QProxyStyle::staticMetaObject, qt_meta_stringdata_PCManFM__ProxyStyle.data,
      qt_meta_data_PCManFM__ProxyStyle,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PCManFM::ProxyStyle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::ProxyStyle::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PCManFM__ProxyStyle.stringdata0))
        return static_cast<void*>(const_cast< ProxyStyle*>(this));
    return QProxyStyle::qt_metacast(_clname);
}

int PCManFM::ProxyStyle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QProxyStyle::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
struct qt_meta_stringdata_PCManFM__Application_t {
    QByteArrayData data[24];
    char stringdata0[358];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PCManFM__Application_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PCManFM__Application_t qt_meta_stringdata_PCManFM__Application = {
    {
QT_MOC_LITERAL(0, 0, 20), // "PCManFM::Application"
QT_MOC_LITERAL(1, 21, 13), // "onAboutToQuit"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 17), // "onSigtermNotified"
QT_MOC_LITERAL(4, 54, 18), // "onLastWindowClosed"
QT_MOC_LITERAL(5, 73, 18), // "onSaveStateRequest"
QT_MOC_LITERAL(6, 92, 16), // "QSessionManager&"
QT_MOC_LITERAL(7, 109, 7), // "manager"
QT_MOC_LITERAL(8, 117, 15), // "onScreenResized"
QT_MOC_LITERAL(9, 133, 3), // "num"
QT_MOC_LITERAL(10, 137, 20), // "onScreenCountChanged"
QT_MOC_LITERAL(11, 158, 8), // "newCount"
QT_MOC_LITERAL(12, 167, 17), // "initVolumeManager"
QT_MOC_LITERAL(13, 185, 24), // "onVirtualGeometryChanged"
QT_MOC_LITERAL(14, 210, 4), // "rect"
QT_MOC_LITERAL(15, 215, 17), // "onScreenDestroyed"
QT_MOC_LITERAL(16, 233, 9), // "screenObj"
QT_MOC_LITERAL(17, 243, 13), // "onScreenAdded"
QT_MOC_LITERAL(18, 257, 8), // "QScreen*"
QT_MOC_LITERAL(19, 266, 9), // "newScreen"
QT_MOC_LITERAL(20, 276, 22), // "reloadDesktopsAsNeeded"
QT_MOC_LITERAL(21, 299, 18), // "onFindFileAccepted"
QT_MOC_LITERAL(22, 318, 17), // "onUserDirsChanged"
QT_MOC_LITERAL(23, 336, 21) // "desktopManagerEnabled"

    },
    "PCManFM::Application\0onAboutToQuit\0\0"
    "onSigtermNotified\0onLastWindowClosed\0"
    "onSaveStateRequest\0QSessionManager&\0"
    "manager\0onScreenResized\0num\0"
    "onScreenCountChanged\0newCount\0"
    "initVolumeManager\0onVirtualGeometryChanged\0"
    "rect\0onScreenDestroyed\0screenObj\0"
    "onScreenAdded\0QScreen*\0newScreen\0"
    "reloadDesktopsAsNeeded\0onFindFileAccepted\0"
    "onUserDirsChanged\0desktopManagerEnabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PCManFM__Application[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       1,  104, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x09 /* Protected */,
       3,    0,   80,    2, 0x09 /* Protected */,
       4,    0,   81,    2, 0x09 /* Protected */,
       5,    1,   82,    2, 0x09 /* Protected */,
       8,    1,   85,    2, 0x09 /* Protected */,
      10,    1,   88,    2, 0x09 /* Protected */,
      12,    0,   91,    2, 0x09 /* Protected */,
      13,    1,   92,    2, 0x09 /* Protected */,
      15,    1,   95,    2, 0x09 /* Protected */,
      17,    1,   98,    2, 0x09 /* Protected */,
      20,    0,  101,    2, 0x09 /* Protected */,
      21,    0,  102,    2, 0x09 /* Protected */,
      22,    0,  103,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QRect,   14,
    QMetaType::Void, QMetaType::QObjectStar,   16,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      23, QMetaType::Bool, 0x00095001,

       0        // eod
};

void PCManFM::Application::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Application *_t = static_cast<Application *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onAboutToQuit(); break;
        case 1: _t->onSigtermNotified(); break;
        case 2: _t->onLastWindowClosed(); break;
        case 3: _t->onSaveStateRequest((*reinterpret_cast< QSessionManager(*)>(_a[1]))); break;
        case 4: _t->onScreenResized((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->onScreenCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->initVolumeManager(); break;
        case 7: _t->onVirtualGeometryChanged((*reinterpret_cast< const QRect(*)>(_a[1]))); break;
        case 8: _t->onScreenDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 9: _t->onScreenAdded((*reinterpret_cast< QScreen*(*)>(_a[1]))); break;
        case 10: _t->reloadDesktopsAsNeeded(); break;
        case 11: _t->onFindFileAccepted(); break;
        case 12: _t->onUserDirsChanged(); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        Application *_t = static_cast<Application *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->desktopManagerEnabled(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject PCManFM::Application::staticMetaObject = {
    { &QApplication::staticMetaObject, qt_meta_stringdata_PCManFM__Application.data,
      qt_meta_data_PCManFM__Application,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PCManFM::Application::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::Application::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PCManFM__Application.stringdata0))
        return static_cast<void*>(const_cast< Application*>(this));
    return QApplication::qt_metacast(_clname);
}

int PCManFM::Application::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_END_MOC_NAMESPACE
