/****************************************************************************
** Meta object code from reading C++ file 'desktopwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/pcmanfm-qt-0.11.1/pcmanfm/desktopwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'desktopwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_PCManFM__DesktopWindow_t {
    QByteArrayData data[26];
    char stringdata0[371];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PCManFM__DesktopWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PCManFM__DesktopWindow_t qt_meta_stringdata_PCManFM__DesktopWindow = {
    {
QT_MOC_LITERAL(0, 0, 22), // "PCManFM::DesktopWindow"
QT_MOC_LITERAL(1, 23, 18), // "onOpenDirRequested"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 7), // "FmPath*"
QT_MOC_LITERAL(4, 51, 4), // "path"
QT_MOC_LITERAL(5, 56, 6), // "target"
QT_MOC_LITERAL(6, 63, 20), // "onDesktopPreferences"
QT_MOC_LITERAL(7, 84, 22), // "onRowsAboutToBeRemoved"
QT_MOC_LITERAL(8, 107, 6), // "parent"
QT_MOC_LITERAL(9, 114, 5), // "start"
QT_MOC_LITERAL(10, 120, 3), // "end"
QT_MOC_LITERAL(11, 124, 14), // "onRowsInserted"
QT_MOC_LITERAL(12, 139, 15), // "onLayoutChanged"
QT_MOC_LITERAL(13, 155, 24), // "onModelSortFilterChanged"
QT_MOC_LITERAL(14, 180, 14), // "onIndexesMoved"
QT_MOC_LITERAL(15, 195, 15), // "QModelIndexList"
QT_MOC_LITERAL(16, 211, 7), // "indexes"
QT_MOC_LITERAL(17, 219, 13), // "relayoutItems"
QT_MOC_LITERAL(18, 233, 19), // "onStickToCurrentPos"
QT_MOC_LITERAL(19, 253, 7), // "toggled"
QT_MOC_LITERAL(20, 261, 14), // "onCutActivated"
QT_MOC_LITERAL(21, 276, 15), // "onCopyActivated"
QT_MOC_LITERAL(22, 292, 16), // "onPasteActivated"
QT_MOC_LITERAL(23, 309, 17), // "onRenameActivated"
QT_MOC_LITERAL(24, 327, 17), // "onDeleteActivated"
QT_MOC_LITERAL(25, 345, 25) // "onFilePropertiesActivated"

    },
    "PCManFM::DesktopWindow\0onOpenDirRequested\0"
    "\0FmPath*\0path\0target\0onDesktopPreferences\0"
    "onRowsAboutToBeRemoved\0parent\0start\0"
    "end\0onRowsInserted\0onLayoutChanged\0"
    "onModelSortFilterChanged\0onIndexesMoved\0"
    "QModelIndexList\0indexes\0relayoutItems\0"
    "onStickToCurrentPos\0toggled\0onCutActivated\0"
    "onCopyActivated\0onPasteActivated\0"
    "onRenameActivated\0onDeleteActivated\0"
    "onFilePropertiesActivated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PCManFM__DesktopWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   89,    2, 0x09 /* Protected */,
       6,    0,   94,    2, 0x09 /* Protected */,
       7,    3,   95,    2, 0x09 /* Protected */,
      11,    3,  102,    2, 0x09 /* Protected */,
      12,    0,  109,    2, 0x09 /* Protected */,
      13,    0,  110,    2, 0x09 /* Protected */,
      14,    1,  111,    2, 0x09 /* Protected */,
      17,    0,  114,    2, 0x09 /* Protected */,
      18,    1,  115,    2, 0x09 /* Protected */,
      20,    0,  118,    2, 0x09 /* Protected */,
      21,    0,  119,    2, 0x09 /* Protected */,
      22,    0,  120,    2, 0x09 /* Protected */,
      23,    0,  121,    2, 0x09 /* Protected */,
      24,    0,  122,    2, 0x09 /* Protected */,
      25,    0,  123,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,    8,    9,   10,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,    8,    9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void PCManFM::DesktopWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DesktopWindow *_t = static_cast<DesktopWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onOpenDirRequested((*reinterpret_cast< FmPath*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->onDesktopPreferences(); break;
        case 2: _t->onRowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->onRowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->onLayoutChanged(); break;
        case 5: _t->onModelSortFilterChanged(); break;
        case 6: _t->onIndexesMoved((*reinterpret_cast< const QModelIndexList(*)>(_a[1]))); break;
        case 7: _t->relayoutItems(); break;
        case 8: _t->onStickToCurrentPos((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->onCutActivated(); break;
        case 10: _t->onCopyActivated(); break;
        case 11: _t->onPasteActivated(); break;
        case 12: _t->onRenameActivated(); break;
        case 13: _t->onDeleteActivated(); break;
        case 14: _t->onFilePropertiesActivated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QModelIndexList >(); break;
            }
            break;
        }
    }
}

const QMetaObject PCManFM::DesktopWindow::staticMetaObject = {
    { &View::staticMetaObject, qt_meta_stringdata_PCManFM__DesktopWindow.data,
      qt_meta_data_PCManFM__DesktopWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PCManFM::DesktopWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::DesktopWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PCManFM__DesktopWindow.stringdata0))
        return static_cast<void*>(const_cast< DesktopWindow*>(this));
    return View::qt_metacast(_clname);
}

int PCManFM::DesktopWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = View::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
