/********************************************************************************
** Form generated from reading UI file 'preferences.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCES_H
#define UI_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PreferencesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QListWidget *listWidget;
    QStackedWidget *stackedWidget;
    QWidget *behaviorPage;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox_4;
    QFormLayout *formLayout_5;
    QCheckBox *singleClick;
    QLabel *label;
    QLabel *label_11;
    QComboBox *viewMode;
    QDoubleSpinBox *autoSelectionDelay;
    QLabel *label_2;
    QComboBox *bookmarkOpenMethod;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_9;
    QCheckBox *configmDelete;
    QCheckBox *useTrash;
    QCheckBox *noUsbTrash;
    QCheckBox *confirmTrash;
    QCheckBox *quickExec;
    QSpacerItem *verticalSpacer_2;
    QWidget *displayPage;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout_2;
    QLabel *iconThemeLabel;
    QComboBox *iconTheme;
    QLabel *label_6;
    QComboBox *bigIconSize;
    QLabel *label_7;
    QComboBox *smallIconSize;
    QLabel *label_8;
    QComboBox *thumbnailIconSize;
    QLabel *label_9;
    QComboBox *sidePaneIconSize;
    QGroupBox *groupBox_9;
    QGridLayout *gridLayout;
    QCheckBox *siUnit;
    QCheckBox *backupAsHidden;
    QCheckBox *showFullNames;
    QCheckBox *shadowHidden;
    QSpacerItem *verticalSpacer_7;
    QLabel *label_15;
    QSpinBox *hMargin;
    QLabel *label_16;
    QSpinBox *vMargin;
    QCheckBox *lockMargins;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_5;
    QWidget *uiPage;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBox_5;
    QFormLayout *formLayout_7;
    QCheckBox *alwaysShowTabs;
    QCheckBox *fullWidthTabbar;
    QCheckBox *showTabClose;
    QCheckBox *rememberWindowSize;
    QLabel *label_12;
    QSpinBox *fixedWindowWidth;
    QLabel *label_13;
    QSpinBox *fixedWindowHeight;
    QGroupBox *groupBox_10;
    QVBoxLayout *verticalLayout_10;
    QListWidget *showInPlaces;
    QSpacerItem *verticalSpacer_4;
    QWidget *thumbnailPage;
    QVBoxLayout *verticalLayout_11;
    QGroupBox *groupBox_8;
    QFormLayout *formLayout_3;
    QLabel *label_10;
    QSpinBox *maxThumbnailFileSize;
    QCheckBox *thumbnailLocal;
    QCheckBox *showThumbnails;
    QSpacerItem *verticalSpacer_6;
    QWidget *volumePage;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBox_3;
    QFormLayout *formLayout_4;
    QCheckBox *mountOnStartup;
    QCheckBox *mountRemovable;
    QCheckBox *autoRun;
    QGroupBox *groupBox_7;
    QVBoxLayout *verticalLayout_6;
    QRadioButton *closeOnUnmount;
    QRadioButton *goHomeOnUnmount;
    QSpacerItem *verticalSpacer;
    QWidget *advancedPage;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label_14;
    QLabel *label_3;
    QLineEdit *suCommand;
    QLabel *label_4;
    QLabel *label_5;
    QComboBox *archiver;
    QComboBox *terminal;
    QGroupBox *groupBox_11;
    QVBoxLayout *verticalLayout_12;
    QCheckBox *onlyUserTemplates;
    QCheckBox *templateTypeOnce;
    QCheckBox *templateRunApp;
    QSpacerItem *verticalSpacer_3;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PreferencesDialog)
    {
        if (PreferencesDialog->objectName().isEmpty())
            PreferencesDialog->setObjectName(QStringLiteral("PreferencesDialog"));
        PreferencesDialog->resize(685, 440);
        verticalLayout = new QVBoxLayout(PreferencesDialog);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        listWidget = new QListWidget(PreferencesDialog);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        new QListWidgetItem(listWidget);
        listWidget->setObjectName(QStringLiteral("listWidget"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(listWidget->sizePolicy().hasHeightForWidth());
        listWidget->setSizePolicy(sizePolicy);
        listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        horizontalLayout->addWidget(listWidget);

        stackedWidget = new QStackedWidget(PreferencesDialog);
        stackedWidget->setObjectName(QStringLiteral("stackedWidget"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(stackedWidget->sizePolicy().hasHeightForWidth());
        stackedWidget->setSizePolicy(sizePolicy1);
        behaviorPage = new QWidget();
        behaviorPage->setObjectName(QStringLiteral("behaviorPage"));
        verticalLayout_3 = new QVBoxLayout(behaviorPage);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        groupBox_4 = new QGroupBox(behaviorPage);
        groupBox_4->setObjectName(QStringLiteral("groupBox_4"));
        formLayout_5 = new QFormLayout(groupBox_4);
        formLayout_5->setObjectName(QStringLiteral("formLayout_5"));
        formLayout_5->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        singleClick = new QCheckBox(groupBox_4);
        singleClick->setObjectName(QStringLiteral("singleClick"));

        formLayout_5->setWidget(0, QFormLayout::SpanningRole, singleClick);

        label = new QLabel(groupBox_4);
        label->setObjectName(QStringLiteral("label"));
        label->setEnabled(false);

        formLayout_5->setWidget(1, QFormLayout::LabelRole, label);

        label_11 = new QLabel(groupBox_4);
        label_11->setObjectName(QStringLiteral("label_11"));

        formLayout_5->setWidget(3, QFormLayout::LabelRole, label_11);

        viewMode = new QComboBox(groupBox_4);
        viewMode->setObjectName(QStringLiteral("viewMode"));

        formLayout_5->setWidget(3, QFormLayout::FieldRole, viewMode);

        autoSelectionDelay = new QDoubleSpinBox(groupBox_4);
        autoSelectionDelay->setObjectName(QStringLiteral("autoSelectionDelay"));
        autoSelectionDelay->setEnabled(false);
        autoSelectionDelay->setSingleStep(0.1);

        formLayout_5->setWidget(1, QFormLayout::FieldRole, autoSelectionDelay);

        label_2 = new QLabel(groupBox_4);
        label_2->setObjectName(QStringLiteral("label_2"));

        formLayout_5->setWidget(2, QFormLayout::LabelRole, label_2);

        bookmarkOpenMethod = new QComboBox(groupBox_4);
        bookmarkOpenMethod->setObjectName(QStringLiteral("bookmarkOpenMethod"));

        formLayout_5->setWidget(2, QFormLayout::FieldRole, bookmarkOpenMethod);


        verticalLayout_3->addWidget(groupBox_4);

        groupBox_6 = new QGroupBox(behaviorPage);
        groupBox_6->setObjectName(QStringLiteral("groupBox_6"));
        verticalLayout_9 = new QVBoxLayout(groupBox_6);
        verticalLayout_9->setObjectName(QStringLiteral("verticalLayout_9"));
        configmDelete = new QCheckBox(groupBox_6);
        configmDelete->setObjectName(QStringLiteral("configmDelete"));

        verticalLayout_9->addWidget(configmDelete);

        useTrash = new QCheckBox(groupBox_6);
        useTrash->setObjectName(QStringLiteral("useTrash"));

        verticalLayout_9->addWidget(useTrash);

        noUsbTrash = new QCheckBox(groupBox_6);
        noUsbTrash->setObjectName(QStringLiteral("noUsbTrash"));

        verticalLayout_9->addWidget(noUsbTrash);

        confirmTrash = new QCheckBox(groupBox_6);
        confirmTrash->setObjectName(QStringLiteral("confirmTrash"));

        verticalLayout_9->addWidget(confirmTrash);

        quickExec = new QCheckBox(groupBox_6);
        quickExec->setObjectName(QStringLiteral("quickExec"));

        verticalLayout_9->addWidget(quickExec);


        verticalLayout_3->addWidget(groupBox_6);

        verticalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        verticalLayout_3->setStretch(2, 1);
        stackedWidget->addWidget(behaviorPage);
        displayPage = new QWidget();
        displayPage->setObjectName(QStringLiteral("displayPage"));
        verticalLayout_7 = new QVBoxLayout(displayPage);
        verticalLayout_7->setObjectName(QStringLiteral("verticalLayout_7"));
        groupBox_2 = new QGroupBox(displayPage);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        formLayout_2 = new QFormLayout(groupBox_2);
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        iconThemeLabel = new QLabel(groupBox_2);
        iconThemeLabel->setObjectName(QStringLiteral("iconThemeLabel"));
        QSizePolicy sizePolicy2(QSizePolicy::Fixed, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(iconThemeLabel->sizePolicy().hasHeightForWidth());
        iconThemeLabel->setSizePolicy(sizePolicy2);

        formLayout_2->setWidget(0, QFormLayout::LabelRole, iconThemeLabel);

        iconTheme = new QComboBox(groupBox_2);
        iconTheme->setObjectName(QStringLiteral("iconTheme"));
        QSizePolicy sizePolicy3(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(iconTheme->sizePolicy().hasHeightForWidth());
        iconTheme->setSizePolicy(sizePolicy3);

        formLayout_2->setWidget(0, QFormLayout::FieldRole, iconTheme);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName(QStringLiteral("label_6"));

        formLayout_2->setWidget(1, QFormLayout::LabelRole, label_6);

        bigIconSize = new QComboBox(groupBox_2);
        bigIconSize->setObjectName(QStringLiteral("bigIconSize"));

        formLayout_2->setWidget(1, QFormLayout::FieldRole, bigIconSize);

        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName(QStringLiteral("label_7"));

        formLayout_2->setWidget(2, QFormLayout::LabelRole, label_7);

        smallIconSize = new QComboBox(groupBox_2);
        smallIconSize->setObjectName(QStringLiteral("smallIconSize"));

        formLayout_2->setWidget(2, QFormLayout::FieldRole, smallIconSize);

        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName(QStringLiteral("label_8"));

        formLayout_2->setWidget(3, QFormLayout::LabelRole, label_8);

        thumbnailIconSize = new QComboBox(groupBox_2);
        thumbnailIconSize->setObjectName(QStringLiteral("thumbnailIconSize"));

        formLayout_2->setWidget(3, QFormLayout::FieldRole, thumbnailIconSize);

        label_9 = new QLabel(groupBox_2);
        label_9->setObjectName(QStringLiteral("label_9"));

        formLayout_2->setWidget(4, QFormLayout::LabelRole, label_9);

        sidePaneIconSize = new QComboBox(groupBox_2);
        sidePaneIconSize->setObjectName(QStringLiteral("sidePaneIconSize"));

        formLayout_2->setWidget(4, QFormLayout::FieldRole, sidePaneIconSize);


        verticalLayout_7->addWidget(groupBox_2);

        groupBox_9 = new QGroupBox(displayPage);
        groupBox_9->setObjectName(QStringLiteral("groupBox_9"));
        gridLayout = new QGridLayout(groupBox_9);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        siUnit = new QCheckBox(groupBox_9);
        siUnit->setObjectName(QStringLiteral("siUnit"));

        gridLayout->addWidget(siUnit, 0, 0, 1, 6);

        backupAsHidden = new QCheckBox(groupBox_9);
        backupAsHidden->setObjectName(QStringLiteral("backupAsHidden"));

        gridLayout->addWidget(backupAsHidden, 1, 0, 1, 6);

        showFullNames = new QCheckBox(groupBox_9);
        showFullNames->setObjectName(QStringLiteral("showFullNames"));
        showFullNames->setEnabled(false);

        gridLayout->addWidget(showFullNames, 2, 0, 1, 6);

        shadowHidden = new QCheckBox(groupBox_9);
        shadowHidden->setObjectName(QStringLiteral("shadowHidden"));
        shadowHidden->setEnabled(false);

        gridLayout->addWidget(shadowHidden, 3, 0, 1, 6);

        verticalSpacer_7 = new QSpacerItem(20, 5, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(verticalSpacer_7, 4, 0, 1, 1);

        label_15 = new QLabel(groupBox_9);
        label_15->setObjectName(QStringLiteral("label_15"));

        gridLayout->addWidget(label_15, 5, 0, 1, 1);

        hMargin = new QSpinBox(groupBox_9);
        hMargin->setObjectName(QStringLiteral("hMargin"));
        hMargin->setMaximum(48);
        hMargin->setValue(3);

        gridLayout->addWidget(hMargin, 5, 1, 1, 1);

        label_16 = new QLabel(groupBox_9);
        label_16->setObjectName(QStringLiteral("label_16"));

        gridLayout->addWidget(label_16, 5, 2, 1, 1);

        vMargin = new QSpinBox(groupBox_9);
        vMargin->setObjectName(QStringLiteral("vMargin"));
        vMargin->setMaximum(48);
        vMargin->setValue(3);

        gridLayout->addWidget(vMargin, 5, 3, 1, 1);

        lockMargins = new QCheckBox(groupBox_9);
        lockMargins->setObjectName(QStringLiteral("lockMargins"));

        gridLayout->addWidget(lockMargins, 5, 4, 1, 1);

        horizontalSpacer = new QSpacerItem(20, 5, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 5, 5, 1, 1);


        verticalLayout_7->addWidget(groupBox_9);

        verticalSpacer_5 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_7->addItem(verticalSpacer_5);

        verticalLayout_7->setStretch(2, 1);
        stackedWidget->addWidget(displayPage);
        uiPage = new QWidget();
        uiPage->setObjectName(QStringLiteral("uiPage"));
        verticalLayout_5 = new QVBoxLayout(uiPage);
        verticalLayout_5->setObjectName(QStringLiteral("verticalLayout_5"));
        groupBox_5 = new QGroupBox(uiPage);
        groupBox_5->setObjectName(QStringLiteral("groupBox_5"));
        formLayout_7 = new QFormLayout(groupBox_5);
        formLayout_7->setObjectName(QStringLiteral("formLayout_7"));
        formLayout_7->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        alwaysShowTabs = new QCheckBox(groupBox_5);
        alwaysShowTabs->setObjectName(QStringLiteral("alwaysShowTabs"));

        formLayout_7->setWidget(0, QFormLayout::SpanningRole, alwaysShowTabs);

        fullWidthTabbar = new QCheckBox(groupBox_5);
        fullWidthTabbar->setObjectName(QStringLiteral("fullWidthTabbar"));

        formLayout_7->setWidget(1, QFormLayout::SpanningRole, fullWidthTabbar);

        showTabClose = new QCheckBox(groupBox_5);
        showTabClose->setObjectName(QStringLiteral("showTabClose"));

        formLayout_7->setWidget(2, QFormLayout::SpanningRole, showTabClose);

        rememberWindowSize = new QCheckBox(groupBox_5);
        rememberWindowSize->setObjectName(QStringLiteral("rememberWindowSize"));

        formLayout_7->setWidget(3, QFormLayout::SpanningRole, rememberWindowSize);

        label_12 = new QLabel(groupBox_5);
        label_12->setObjectName(QStringLiteral("label_12"));

        formLayout_7->setWidget(4, QFormLayout::LabelRole, label_12);

        fixedWindowWidth = new QSpinBox(groupBox_5);
        fixedWindowWidth->setObjectName(QStringLiteral("fixedWindowWidth"));
        fixedWindowWidth->setMaximum(32768);

        formLayout_7->setWidget(4, QFormLayout::FieldRole, fixedWindowWidth);

        label_13 = new QLabel(groupBox_5);
        label_13->setObjectName(QStringLiteral("label_13"));

        formLayout_7->setWidget(5, QFormLayout::LabelRole, label_13);

        fixedWindowHeight = new QSpinBox(groupBox_5);
        fixedWindowHeight->setObjectName(QStringLiteral("fixedWindowHeight"));
        fixedWindowHeight->setMaximum(32768);

        formLayout_7->setWidget(5, QFormLayout::FieldRole, fixedWindowHeight);


        verticalLayout_5->addWidget(groupBox_5);

        groupBox_10 = new QGroupBox(uiPage);
        groupBox_10->setObjectName(QStringLiteral("groupBox_10"));
        verticalLayout_10 = new QVBoxLayout(groupBox_10);
        verticalLayout_10->setObjectName(QStringLiteral("verticalLayout_10"));
        showInPlaces = new QListWidget(groupBox_10);
        QIcon icon;
        QString iconThemeName = QStringLiteral("user-home");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(showInPlaces);
        __qlistwidgetitem->setCheckState(Qt::Unchecked);
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1;
        iconThemeName = QStringLiteral("user-desktop");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(showInPlaces);
        __qlistwidgetitem1->setCheckState(Qt::Unchecked);
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2;
        iconThemeName = QStringLiteral("user-trash");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(showInPlaces);
        __qlistwidgetitem2->setCheckState(Qt::Unchecked);
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3;
        iconThemeName = QStringLiteral("computer");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(showInPlaces);
        __qlistwidgetitem3->setCheckState(Qt::Unchecked);
        __qlistwidgetitem3->setIcon(icon3);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(showInPlaces);
        __qlistwidgetitem4->setCheckState(Qt::Unchecked);
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(showInPlaces);
        __qlistwidgetitem5->setCheckState(Qt::Unchecked);
        QIcon icon4;
        iconThemeName = QStringLiteral("folder-network");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(showInPlaces);
        __qlistwidgetitem6->setCheckState(Qt::Unchecked);
        __qlistwidgetitem6->setIcon(icon4);
        showInPlaces->setObjectName(QStringLiteral("showInPlaces"));

        verticalLayout_10->addWidget(showInPlaces);


        verticalLayout_5->addWidget(groupBox_10);

        verticalSpacer_4 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_4);

        verticalLayout_5->setStretch(2, 1);
        stackedWidget->addWidget(uiPage);
        thumbnailPage = new QWidget();
        thumbnailPage->setObjectName(QStringLiteral("thumbnailPage"));
        verticalLayout_11 = new QVBoxLayout(thumbnailPage);
        verticalLayout_11->setObjectName(QStringLiteral("verticalLayout_11"));
        groupBox_8 = new QGroupBox(thumbnailPage);
        groupBox_8->setObjectName(QStringLiteral("groupBox_8"));
        formLayout_3 = new QFormLayout(groupBox_8);
        formLayout_3->setObjectName(QStringLiteral("formLayout_3"));
        label_10 = new QLabel(groupBox_8);
        label_10->setObjectName(QStringLiteral("label_10"));

        formLayout_3->setWidget(2, QFormLayout::LabelRole, label_10);

        maxThumbnailFileSize = new QSpinBox(groupBox_8);
        maxThumbnailFileSize->setObjectName(QStringLiteral("maxThumbnailFileSize"));
        maxThumbnailFileSize->setMaximum(1048576);

        formLayout_3->setWidget(2, QFormLayout::FieldRole, maxThumbnailFileSize);

        thumbnailLocal = new QCheckBox(groupBox_8);
        thumbnailLocal->setObjectName(QStringLiteral("thumbnailLocal"));

        formLayout_3->setWidget(1, QFormLayout::SpanningRole, thumbnailLocal);

        showThumbnails = new QCheckBox(groupBox_8);
        showThumbnails->setObjectName(QStringLiteral("showThumbnails"));

        formLayout_3->setWidget(0, QFormLayout::SpanningRole, showThumbnails);


        verticalLayout_11->addWidget(groupBox_8);

        verticalSpacer_6 = new QSpacerItem(0, 225, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_11->addItem(verticalSpacer_6);

        stackedWidget->addWidget(thumbnailPage);
        volumePage = new QWidget();
        volumePage->setObjectName(QStringLiteral("volumePage"));
        verticalLayout_4 = new QVBoxLayout(volumePage);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        groupBox_3 = new QGroupBox(volumePage);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        formLayout_4 = new QFormLayout(groupBox_3);
        formLayout_4->setObjectName(QStringLiteral("formLayout_4"));
        mountOnStartup = new QCheckBox(groupBox_3);
        mountOnStartup->setObjectName(QStringLiteral("mountOnStartup"));

        formLayout_4->setWidget(0, QFormLayout::LabelRole, mountOnStartup);

        mountRemovable = new QCheckBox(groupBox_3);
        mountRemovable->setObjectName(QStringLiteral("mountRemovable"));

        formLayout_4->setWidget(1, QFormLayout::LabelRole, mountRemovable);

        autoRun = new QCheckBox(groupBox_3);
        autoRun->setObjectName(QStringLiteral("autoRun"));

        formLayout_4->setWidget(2, QFormLayout::LabelRole, autoRun);


        verticalLayout_4->addWidget(groupBox_3);

        groupBox_7 = new QGroupBox(volumePage);
        groupBox_7->setObjectName(QStringLiteral("groupBox_7"));
        verticalLayout_6 = new QVBoxLayout(groupBox_7);
        verticalLayout_6->setObjectName(QStringLiteral("verticalLayout_6"));
        closeOnUnmount = new QRadioButton(groupBox_7);
        closeOnUnmount->setObjectName(QStringLiteral("closeOnUnmount"));

        verticalLayout_6->addWidget(closeOnUnmount);

        goHomeOnUnmount = new QRadioButton(groupBox_7);
        goHomeOnUnmount->setObjectName(QStringLiteral("goHomeOnUnmount"));

        verticalLayout_6->addWidget(goHomeOnUnmount);


        verticalLayout_4->addWidget(groupBox_7);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        verticalLayout_4->setStretch(2, 1);
        stackedWidget->addWidget(volumePage);
        advancedPage = new QWidget();
        advancedPage->setObjectName(QStringLiteral("advancedPage"));
        verticalLayout_2 = new QVBoxLayout(advancedPage);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        groupBox = new QGroupBox(advancedPage);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_14 = new QLabel(groupBox);
        label_14->setObjectName(QStringLiteral("label_14"));

        formLayout->setWidget(0, QFormLayout::LabelRole, label_14);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName(QStringLiteral("label_3"));

        formLayout->setWidget(1, QFormLayout::LabelRole, label_3);

        suCommand = new QLineEdit(groupBox);
        suCommand->setObjectName(QStringLiteral("suCommand"));

        formLayout->setWidget(1, QFormLayout::FieldRole, suCommand);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName(QStringLiteral("label_4"));
        label_4->setTextFormat(Qt::PlainText);

        formLayout->setWidget(2, QFormLayout::SpanningRole, label_4);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName(QStringLiteral("label_5"));

        formLayout->setWidget(3, QFormLayout::LabelRole, label_5);

        archiver = new QComboBox(groupBox);
        archiver->setObjectName(QStringLiteral("archiver"));

        formLayout->setWidget(3, QFormLayout::FieldRole, archiver);

        terminal = new QComboBox(groupBox);
        terminal->setObjectName(QStringLiteral("terminal"));
        terminal->setEditable(true);

        formLayout->setWidget(0, QFormLayout::FieldRole, terminal);


        verticalLayout_2->addWidget(groupBox);

        groupBox_11 = new QGroupBox(advancedPage);
        groupBox_11->setObjectName(QStringLiteral("groupBox_11"));
        verticalLayout_12 = new QVBoxLayout(groupBox_11);
        verticalLayout_12->setObjectName(QStringLiteral("verticalLayout_12"));
        onlyUserTemplates = new QCheckBox(groupBox_11);
        onlyUserTemplates->setObjectName(QStringLiteral("onlyUserTemplates"));

        verticalLayout_12->addWidget(onlyUserTemplates);

        templateTypeOnce = new QCheckBox(groupBox_11);
        templateTypeOnce->setObjectName(QStringLiteral("templateTypeOnce"));

        verticalLayout_12->addWidget(templateTypeOnce);

        templateRunApp = new QCheckBox(groupBox_11);
        templateRunApp->setObjectName(QStringLiteral("templateRunApp"));

        verticalLayout_12->addWidget(templateRunApp);


        verticalLayout_2->addWidget(groupBox_11);

        verticalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);

        verticalLayout_2->setStretch(2, 1);
        stackedWidget->addWidget(advancedPage);

        horizontalLayout->addWidget(stackedWidget);


        verticalLayout->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(PreferencesDialog);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#ifndef QT_NO_SHORTCUT
        label_3->setBuddy(suCommand);
        label_5->setBuddy(archiver);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(listWidget, alwaysShowTabs);
        QWidget::setTabOrder(alwaysShowTabs, showTabClose);
        QWidget::setTabOrder(showTabClose, rememberWindowSize);
        QWidget::setTabOrder(rememberWindowSize, fixedWindowWidth);
        QWidget::setTabOrder(fixedWindowWidth, fixedWindowHeight);
        QWidget::setTabOrder(fixedWindowHeight, singleClick);
        QWidget::setTabOrder(singleClick, autoSelectionDelay);
        QWidget::setTabOrder(autoSelectionDelay, viewMode);
        QWidget::setTabOrder(viewMode, configmDelete);
        QWidget::setTabOrder(configmDelete, useTrash);
        QWidget::setTabOrder(useTrash, mountOnStartup);
        QWidget::setTabOrder(mountOnStartup, mountRemovable);
        QWidget::setTabOrder(mountRemovable, autoRun);
        QWidget::setTabOrder(autoRun, closeOnUnmount);
        QWidget::setTabOrder(closeOnUnmount, goHomeOnUnmount);
        QWidget::setTabOrder(goHomeOnUnmount, terminal);
        QWidget::setTabOrder(terminal, suCommand);
        QWidget::setTabOrder(suCommand, archiver);

        retranslateUi(PreferencesDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), PreferencesDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), PreferencesDialog, SLOT(reject()));
        QObject::connect(listWidget, SIGNAL(currentRowChanged(int)), stackedWidget, SLOT(setCurrentIndex(int)));
        QObject::connect(singleClick, SIGNAL(toggled(bool)), label, SLOT(setEnabled(bool)));
        QObject::connect(rememberWindowSize, SIGNAL(toggled(bool)), fixedWindowWidth, SLOT(setDisabled(bool)));
        QObject::connect(singleClick, SIGNAL(toggled(bool)), autoSelectionDelay, SLOT(setEnabled(bool)));
        QObject::connect(rememberWindowSize, SIGNAL(toggled(bool)), fixedWindowHeight, SLOT(setDisabled(bool)));
        QObject::connect(rememberWindowSize, SIGNAL(toggled(bool)), label_12, SLOT(setDisabled(bool)));
        QObject::connect(rememberWindowSize, SIGNAL(toggled(bool)), label_13, SLOT(setDisabled(bool)));

        listWidget->setCurrentRow(-1);
        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PreferencesDialog);
    } // setupUi

    void retranslateUi(QDialog *PreferencesDialog)
    {
        PreferencesDialog->setWindowTitle(QApplication::translate("PreferencesDialog", "Preferences", 0));

        const bool __sortingEnabled = listWidget->isSortingEnabled();
        listWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listWidget->item(0);
        ___qlistwidgetitem->setText(QApplication::translate("PreferencesDialog", "Behavior", 0));
        QListWidgetItem *___qlistwidgetitem1 = listWidget->item(1);
        ___qlistwidgetitem1->setText(QApplication::translate("PreferencesDialog", "Display", 0));
        QListWidgetItem *___qlistwidgetitem2 = listWidget->item(2);
        ___qlistwidgetitem2->setText(QApplication::translate("PreferencesDialog", "User Interface", 0));
        QListWidgetItem *___qlistwidgetitem3 = listWidget->item(3);
        ___qlistwidgetitem3->setText(QApplication::translate("PreferencesDialog", "Thumbnail", 0));
        QListWidgetItem *___qlistwidgetitem4 = listWidget->item(4);
        ___qlistwidgetitem4->setText(QApplication::translate("PreferencesDialog", "Volume", 0));
        QListWidgetItem *___qlistwidgetitem5 = listWidget->item(5);
        ___qlistwidgetitem5->setText(QApplication::translate("PreferencesDialog", "Advanced", 0));
        listWidget->setSortingEnabled(__sortingEnabled);

        groupBox_4->setTitle(QApplication::translate("PreferencesDialog", "Browsing", 0));
        singleClick->setText(QApplication::translate("PreferencesDialog", "Open files with single click", 0));
        label->setText(QApplication::translate("PreferencesDialog", "Delay of auto-selection in single click mode (0 to disable)", 0));
        label_11->setText(QApplication::translate("PreferencesDialog", "Default view mode:", 0));
        autoSelectionDelay->setSuffix(QApplication::translate("PreferencesDialog", " sec", 0));
        label_2->setText(QApplication::translate("PreferencesDialog", "Bookmarks:", 0));
        bookmarkOpenMethod->clear();
        bookmarkOpenMethod->insertItems(0, QStringList()
         << QApplication::translate("PreferencesDialog", "Open in current tab", 0)
         << QApplication::translate("PreferencesDialog", "Open in new tab", 0)
         << QApplication::translate("PreferencesDialog", "Open in new window", 0)
        );
        groupBox_6->setTitle(QApplication::translate("PreferencesDialog", "File Operations", 0));
        configmDelete->setText(QApplication::translate("PreferencesDialog", "Confirm before deleting files", 0));
        useTrash->setText(QApplication::translate("PreferencesDialog", "Move deleted files to \"trash bin\" instead of erasing from disk.", 0));
        noUsbTrash->setText(QApplication::translate("PreferencesDialog", "Erase files on removable media instead of \"trash can\" creation", 0));
        confirmTrash->setText(QApplication::translate("PreferencesDialog", "Confirm before moving files into \"trash can\"", 0));
        quickExec->setText(QApplication::translate("PreferencesDialog", "Don't ask options on launch executable file", 0));
        groupBox_2->setTitle(QApplication::translate("PreferencesDialog", "Icons", 0));
        iconThemeLabel->setText(QApplication::translate("PreferencesDialog", "Icon theme:", 0));
#ifndef QT_NO_TOOLTIP
        label_6->setToolTip(QApplication::translate("PreferencesDialog", "Used by Icon View", 0));
#endif // QT_NO_TOOLTIP
        label_6->setText(QApplication::translate("PreferencesDialog", "Size of big icons:", 0));
#ifndef QT_NO_TOOLTIP
        bigIconSize->setToolTip(QApplication::translate("PreferencesDialog", "Used by Icon View", 0));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        label_7->setToolTip(QApplication::translate("PreferencesDialog", "Used by Compact View and Detailed List View", 0));
#endif // QT_NO_TOOLTIP
        label_7->setText(QApplication::translate("PreferencesDialog", "Size of small icons:", 0));
#ifndef QT_NO_TOOLTIP
        smallIconSize->setToolTip(QApplication::translate("PreferencesDialog", "Used by Compact View and Detailed List View", 0));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        label_8->setToolTip(QApplication::translate("PreferencesDialog", "Used by Thumbnail View", 0));
#endif // QT_NO_TOOLTIP
        label_8->setText(QApplication::translate("PreferencesDialog", "Size of thumbnails:", 0));
#ifndef QT_NO_TOOLTIP
        thumbnailIconSize->setToolTip(QApplication::translate("PreferencesDialog", "Used by Thumbnail View", 0));
#endif // QT_NO_TOOLTIP
        label_9->setText(QApplication::translate("PreferencesDialog", "Size of side pane icons:", 0));
        groupBox_9->setTitle(QApplication::translate("PreferencesDialog", "User interface", 0));
        siUnit->setText(QApplication::translate("PreferencesDialog", "Use SI decimal prefixes instead of IEC binary prefixes", 0));
        backupAsHidden->setText(QApplication::translate("PreferencesDialog", "Treat backup files as hidden", 0));
        showFullNames->setText(QApplication::translate("PreferencesDialog", "Always show full file names", 0));
        shadowHidden->setText(QApplication::translate("PreferencesDialog", "Show icons of hidden files shadowed", 0));
        label_15->setText(QApplication::translate("PreferencesDialog", "Minimum item margins in icon view:", 0));
#ifndef QT_NO_TOOLTIP
        hMargin->setToolTip(QApplication::translate("PreferencesDialog", "3 px by default.", 0));
#endif // QT_NO_TOOLTIP
        hMargin->setSuffix(QApplication::translate("PreferencesDialog", " px", 0));
        label_16->setText(QApplication::translate("PreferencesDialog", "x", 0));
#ifndef QT_NO_TOOLTIP
        vMargin->setToolTip(QApplication::translate("PreferencesDialog", "3 px by default.\n"
"A space is also reserved for 3 lines of text.", 0));
#endif // QT_NO_TOOLTIP
        vMargin->setSuffix(QApplication::translate("PreferencesDialog", " px", 0));
        lockMargins->setText(QApplication::translate("PreferencesDialog", "Lock", 0));
        groupBox_5->setTitle(QApplication::translate("PreferencesDialog", "Window", 0));
#ifndef QT_NO_TOOLTIP
        alwaysShowTabs->setToolTip(QApplication::translate("PreferencesDialog", "When unchecked, the tab bar will be shown\n"
"only if there are more than one tab.", 0));
#endif // QT_NO_TOOLTIP
        alwaysShowTabs->setText(QApplication::translate("PreferencesDialog", "Always show the tab bar", 0));
#ifndef QT_NO_TOOLTIP
        fullWidthTabbar->setToolTip(QApplication::translate("PreferencesDialog", "If unchecked, the tab bar will be positioned only\n"
"above the folder-view and not above the left pane.", 0));
#endif // QT_NO_TOOLTIP
        fullWidthTabbar->setText(QApplication::translate("PreferencesDialog", "Fullwidth tab bar", 0));
        showTabClose->setText(QApplication::translate("PreferencesDialog", "Show 'Close' buttons on tabs	", 0));
        rememberWindowSize->setText(QApplication::translate("PreferencesDialog", "Remember the size of the last closed window", 0));
        label_12->setText(QApplication::translate("PreferencesDialog", "Default width of new windows:", 0));
        label_13->setText(QApplication::translate("PreferencesDialog", "Default height of new windows:", 0));
        groupBox_10->setTitle(QApplication::translate("PreferencesDialog", "Show in places", 0));

        const bool __sortingEnabled1 = showInPlaces->isSortingEnabled();
        showInPlaces->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem6 = showInPlaces->item(0);
        ___qlistwidgetitem6->setText(QApplication::translate("PreferencesDialog", "Home", 0));
        QListWidgetItem *___qlistwidgetitem7 = showInPlaces->item(1);
        ___qlistwidgetitem7->setText(QApplication::translate("PreferencesDialog", "Desktop", 0));
        QListWidgetItem *___qlistwidgetitem8 = showInPlaces->item(2);
        ___qlistwidgetitem8->setText(QApplication::translate("PreferencesDialog", "Trash can", 0));
        QListWidgetItem *___qlistwidgetitem9 = showInPlaces->item(3);
        ___qlistwidgetitem9->setText(QApplication::translate("PreferencesDialog", "Computer", 0));
        QListWidgetItem *___qlistwidgetitem10 = showInPlaces->item(4);
        ___qlistwidgetitem10->setText(QApplication::translate("PreferencesDialog", "Applications", 0));
        QListWidgetItem *___qlistwidgetitem11 = showInPlaces->item(5);
        ___qlistwidgetitem11->setText(QApplication::translate("PreferencesDialog", "Devices", 0));
        QListWidgetItem *___qlistwidgetitem12 = showInPlaces->item(6);
        ___qlistwidgetitem12->setText(QApplication::translate("PreferencesDialog", "Network", 0));
        showInPlaces->setSortingEnabled(__sortingEnabled1);

        groupBox_8->setTitle(QApplication::translate("PreferencesDialog", "Thumbnail", 0));
        label_10->setText(QApplication::translate("PreferencesDialog", "Do not generate thumbnails for image files exceeding this size:", 0));
        maxThumbnailFileSize->setSuffix(QApplication::translate("PreferencesDialog", " KB", 0));
        thumbnailLocal->setText(QApplication::translate("PreferencesDialog", "Only show thumbnails for local files", 0));
#ifndef QT_NO_TOOLTIP
        showThumbnails->setToolTip(QApplication::translate("PreferencesDialog", "Needs ffmpegthumbnailer", 0));
#endif // QT_NO_TOOLTIP
        showThumbnails->setText(QApplication::translate("PreferencesDialog", "Show thumbnails of files", 0));
        groupBox_3->setTitle(QApplication::translate("PreferencesDialog", "Auto Mount", 0));
        mountOnStartup->setText(QApplication::translate("PreferencesDialog", "Mount mountable volumes automatically on program startup", 0));
        mountRemovable->setText(QApplication::translate("PreferencesDialog", "Mount removable media automatically when they are inserted", 0));
        autoRun->setText(QApplication::translate("PreferencesDialog", "Show available options for removable media when they are inserted", 0));
        groupBox_7->setTitle(QApplication::translate("PreferencesDialog", "When removable medium unmounted:", 0));
        closeOnUnmount->setText(QApplication::translate("PreferencesDialog", "Close &tab containing removable medium", 0));
        goHomeOnUnmount->setText(QApplication::translate("PreferencesDialog", "Chan&ge folder in the tab to home folder", 0));
        groupBox->setTitle(QApplication::translate("PreferencesDialog", "Programs", 0));
        label_14->setText(QApplication::translate("PreferencesDialog", "Terminal emulator:", 0));
        label_3->setText(QApplication::translate("PreferencesDialog", "Switch &user command:", 0));
        label_4->setText(QApplication::translate("PreferencesDialog", "Examples: \"xterm -e %s\" for terminal or \"gksu %s\" for switching user.\n"
"%s = the command line you want to execute with terminal or su.", 0));
        label_5->setText(QApplication::translate("PreferencesDialog", "Archiver in&tegration:", 0));
        groupBox_11->setTitle(QApplication::translate("PreferencesDialog", "Templates", 0));
        onlyUserTemplates->setText(QApplication::translate("PreferencesDialog", "Show only user defined templates in menu", 0));
        templateTypeOnce->setText(QApplication::translate("PreferencesDialog", "Show only one template for each MIME type", 0));
        templateRunApp->setText(QApplication::translate("PreferencesDialog", "Run default application after creation from template", 0));
    } // retranslateUi

};

namespace Ui {
    class PreferencesDialog: public Ui_PreferencesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREFERENCES_H
