/****************************************************************************
** Meta object code from reading C++ file 'tabpage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/pcmanfm-qt-0.11.1/pcmanfm/tabpage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_PCManFM__TabPage_t {
    QByteArrayData data[18];
    char stringdata0[213];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PCManFM__TabPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PCManFM__TabPage_t qt_meta_stringdata_PCManFM__TabPage = {
    {
QT_MOC_LITERAL(0, 0, 16), // "PCManFM::TabPage"
QT_MOC_LITERAL(1, 17, 13), // "statusChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 4), // "type"
QT_MOC_LITERAL(4, 37, 10), // "statusText"
QT_MOC_LITERAL(5, 48, 12), // "titleChanged"
QT_MOC_LITERAL(6, 61, 5), // "title"
QT_MOC_LITERAL(7, 67, 16), // "openDirRequested"
QT_MOC_LITERAL(8, 84, 7), // "FmPath*"
QT_MOC_LITERAL(9, 92, 4), // "path"
QT_MOC_LITERAL(10, 97, 6), // "target"
QT_MOC_LITERAL(11, 104, 17), // "sortFilterChanged"
QT_MOC_LITERAL(12, 122, 16), // "forwardRequested"
QT_MOC_LITERAL(13, 139, 17), // "backwardRequested"
QT_MOC_LITERAL(14, 157, 18), // "onOpenDirRequested"
QT_MOC_LITERAL(15, 176, 12), // "onSelChanged"
QT_MOC_LITERAL(16, 189, 6), // "numSel"
QT_MOC_LITERAL(17, 196, 16) // "restoreScrollPos"

    },
    "PCManFM::TabPage\0statusChanged\0\0type\0"
    "statusText\0titleChanged\0title\0"
    "openDirRequested\0FmPath*\0path\0target\0"
    "sortFilterChanged\0forwardRequested\0"
    "backwardRequested\0onOpenDirRequested\0"
    "onSelChanged\0numSel\0restoreScrollPos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PCManFM__TabPage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   59,    2, 0x06 /* Public */,
       5,    1,   64,    2, 0x06 /* Public */,
       7,    2,   67,    2, 0x06 /* Public */,
      11,    0,   72,    2, 0x06 /* Public */,
      12,    0,   73,    2, 0x06 /* Public */,
      13,    0,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    2,   75,    2, 0x09 /* Protected */,
      15,    1,   80,    2, 0x09 /* Protected */,
      17,    0,   83,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    3,    4,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    9,   10,
    QMetaType::Void, QMetaType::Int,   16,
    QMetaType::Void,

       0        // eod
};

void PCManFM::TabPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TabPage *_t = static_cast<TabPage *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 1: _t->titleChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->openDirRequested((*reinterpret_cast< FmPath*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->sortFilterChanged(); break;
        case 4: _t->forwardRequested(); break;
        case 5: _t->backwardRequested(); break;
        case 6: _t->onOpenDirRequested((*reinterpret_cast< FmPath*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->onSelChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->restoreScrollPos(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (TabPage::*_t)(int , QString );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabPage::statusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TabPage::*_t)(QString );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabPage::titleChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TabPage::*_t)(FmPath * , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabPage::openDirRequested)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (TabPage::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabPage::sortFilterChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (TabPage::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabPage::forwardRequested)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (TabPage::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabPage::backwardRequested)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject PCManFM::TabPage::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_PCManFM__TabPage.data,
      qt_meta_data_PCManFM__TabPage,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PCManFM::TabPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::TabPage::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PCManFM__TabPage.stringdata0))
        return static_cast<void*>(const_cast< TabPage*>(this));
    return QWidget::qt_metacast(_clname);
}

int PCManFM::TabPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PCManFM::TabPage::statusChanged(int _t1, QString _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void PCManFM::TabPage::titleChanged(QString _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void PCManFM::TabPage::openDirRequested(FmPath * _t1, int _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void PCManFM::TabPage::sortFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, Q_NULLPTR);
}

// SIGNAL 4
void PCManFM::TabPage::forwardRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}

// SIGNAL 5
void PCManFM::TabPage::backwardRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 5, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
