/********************************************************************************
** Form generated from reading UI file 'desktop-preferences.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DESKTOP_2D_PREFERENCES_H
#define UI_DESKTOP_2D_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <libfm-qt/colorbutton.h>
#include <libfm-qt/fontbutton.h>

QT_BEGIN_NAMESPACE

class Ui_DesktopPreferencesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *generalPage;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QComboBox *wallpaperMode;
    QLabel *label;
    QLabel *label_6;
    Fm::ColorButton *backgroundColor;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QLineEdit *imageFile;
    QPushButton *browse;
    QGroupBox *groupBox_5;
    QFormLayout *formLayout;
    QLabel *label_9;
    QComboBox *iconSize;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    Fm::ColorButton *textColor;
    Fm::ColorButton *shadowColor;
    QLabel *label_3;
    QLabel *label_4;
    QLabel *label_2;
    Fm::FontButton *font;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_3;
    QLabel *label_7;
    QSpinBox *hMargin;
    QLabel *label_8;
    QSpinBox *vMargin;
    QCheckBox *lockMargins;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_2;
    QWidget *advancedPage;
    QVBoxLayout *advancedPageLayout;
    QGroupBox *groupBox_4;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *showWmMenu;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DesktopPreferencesDialog)
    {
        if (DesktopPreferencesDialog->objectName().isEmpty())
            DesktopPreferencesDialog->setObjectName(QStringLiteral("DesktopPreferencesDialog"));
        DesktopPreferencesDialog->resize(534, 434);
        verticalLayout = new QVBoxLayout(DesktopPreferencesDialog);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        tabWidget = new QTabWidget(DesktopPreferencesDialog);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        generalPage = new QWidget();
        generalPage->setObjectName(QStringLiteral("generalPage"));
        verticalLayout_2 = new QVBoxLayout(generalPage);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        groupBox_2 = new QGroupBox(generalPage);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        wallpaperMode = new QComboBox(groupBox_2);
        wallpaperMode->setObjectName(QStringLiteral("wallpaperMode"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(wallpaperMode->sizePolicy().hasHeightForWidth());
        wallpaperMode->setSizePolicy(sizePolicy);

        gridLayout->addWidget(wallpaperMode, 2, 1, 1, 2);

        label = new QLabel(groupBox_2);
        label->setObjectName(QStringLiteral("label"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label, 2, 0, 1, 1);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName(QStringLiteral("label_6"));
        QSizePolicy sizePolicy2(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(label_6, 3, 0, 1, 1);

        backgroundColor = new Fm::ColorButton(groupBox_2);
        backgroundColor->setObjectName(QStringLiteral("backgroundColor"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(backgroundColor->sizePolicy().hasHeightForWidth());
        backgroundColor->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(backgroundColor, 5, 1, 1, 1);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName(QStringLiteral("label_5"));

        gridLayout->addWidget(label_5, 5, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        imageFile = new QLineEdit(groupBox_2);
        imageFile->setObjectName(QStringLiteral("imageFile"));

        horizontalLayout->addWidget(imageFile);

        browse = new QPushButton(groupBox_2);
        browse->setObjectName(QStringLiteral("browse"));

        horizontalLayout->addWidget(browse);


        gridLayout->addLayout(horizontalLayout, 4, 0, 1, 3);


        verticalLayout_2->addWidget(groupBox_2);

        groupBox_5 = new QGroupBox(generalPage);
        groupBox_5->setObjectName(QStringLiteral("groupBox_5"));
        formLayout = new QFormLayout(groupBox_5);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        label_9 = new QLabel(groupBox_5);
        label_9->setObjectName(QStringLiteral("label_9"));

        formLayout->setWidget(0, QFormLayout::LabelRole, label_9);

        iconSize = new QComboBox(groupBox_5);
        iconSize->setObjectName(QStringLiteral("iconSize"));

        formLayout->setWidget(0, QFormLayout::FieldRole, iconSize);


        verticalLayout_2->addWidget(groupBox_5);

        groupBox = new QGroupBox(generalPage);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        textColor = new Fm::ColorButton(groupBox);
        textColor->setObjectName(QStringLiteral("textColor"));
        sizePolicy3.setHeightForWidth(textColor->sizePolicy().hasHeightForWidth());
        textColor->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(textColor, 1, 1, 1, 1);

        shadowColor = new Fm::ColorButton(groupBox);
        shadowColor->setObjectName(QStringLiteral("shadowColor"));
        sizePolicy3.setHeightForWidth(shadowColor->sizePolicy().hasHeightForWidth());
        shadowColor->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(shadowColor, 3, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName(QStringLiteral("label_3"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy4);

        gridLayout_2->addWidget(label_3, 1, 0, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName(QStringLiteral("label_4"));
        sizePolicy4.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy4);

        gridLayout_2->addWidget(label_4, 3, 0, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QStringLiteral("label_2"));
        sizePolicy4.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy4);

        gridLayout_2->addWidget(label_2, 0, 0, 1, 1);

        font = new Fm::FontButton(groupBox);
        font->setObjectName(QStringLiteral("font"));
        QSizePolicy sizePolicy5(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(font->sizePolicy().hasHeightForWidth());
        font->setSizePolicy(sizePolicy5);

        gridLayout_2->addWidget(font, 0, 1, 1, 1);


        verticalLayout_2->addWidget(groupBox);

        groupBox_3 = new QGroupBox(generalPage);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        gridLayout_3 = new QGridLayout(groupBox_3);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName(QStringLiteral("label_7"));

        gridLayout_3->addWidget(label_7, 0, 0, 1, 1);

        hMargin = new QSpinBox(groupBox_3);
        hMargin->setObjectName(QStringLiteral("hMargin"));
        hMargin->setMaximum(48);
        hMargin->setValue(3);

        gridLayout_3->addWidget(hMargin, 0, 1, 1, 1);

        label_8 = new QLabel(groupBox_3);
        label_8->setObjectName(QStringLiteral("label_8"));

        gridLayout_3->addWidget(label_8, 0, 2, 1, 1);

        vMargin = new QSpinBox(groupBox_3);
        vMargin->setObjectName(QStringLiteral("vMargin"));
        vMargin->setMaximum(48);
        vMargin->setValue(1);

        gridLayout_3->addWidget(vMargin, 0, 3, 1, 1);

        lockMargins = new QCheckBox(groupBox_3);
        lockMargins->setObjectName(QStringLiteral("lockMargins"));

        gridLayout_3->addWidget(lockMargins, 0, 4, 1, 1);

        horizontalSpacer = new QSpacerItem(20, 5, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 0, 5, 1, 1);


        verticalLayout_2->addWidget(groupBox_3);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(generalPage, QString());
        advancedPage = new QWidget();
        advancedPage->setObjectName(QStringLiteral("advancedPage"));
        advancedPageLayout = new QVBoxLayout(advancedPage);
        advancedPageLayout->setObjectName(QStringLiteral("advancedPageLayout"));
        groupBox_4 = new QGroupBox(advancedPage);
        groupBox_4->setObjectName(QStringLiteral("groupBox_4"));
        horizontalLayout_3 = new QHBoxLayout(groupBox_4);
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        showWmMenu = new QCheckBox(groupBox_4);
        showWmMenu->setObjectName(QStringLiteral("showWmMenu"));

        horizontalLayout_3->addWidget(showWmMenu);


        advancedPageLayout->addWidget(groupBox_4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        advancedPageLayout->addItem(verticalSpacer);

        tabWidget->addTab(advancedPage, QString());

        verticalLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(DesktopPreferencesDialog);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DesktopPreferencesDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), DesktopPreferencesDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), DesktopPreferencesDialog, SLOT(reject()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DesktopPreferencesDialog);
    } // setupUi

    void retranslateUi(QDialog *DesktopPreferencesDialog)
    {
        DesktopPreferencesDialog->setWindowTitle(QApplication::translate("DesktopPreferencesDialog", "Desktop Preferences", 0));
        groupBox_2->setTitle(QApplication::translate("DesktopPreferencesDialog", "Background", 0));
        label->setText(QApplication::translate("DesktopPreferencesDialog", "Wallpaper mode:", 0));
        label_6->setText(QApplication::translate("DesktopPreferencesDialog", "Wallpaper image file:", 0));
        backgroundColor->setText(QString());
        label_5->setText(QApplication::translate("DesktopPreferencesDialog", "Select background color:", 0));
#ifndef QT_NO_TOOLTIP
        imageFile->setToolTip(QApplication::translate("DesktopPreferencesDialog", "Image file", 0));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_STATUSTIP
        imageFile->setStatusTip(QString());
#endif // QT_NO_STATUSTIP
        imageFile->setPlaceholderText(QApplication::translate("DesktopPreferencesDialog", "Image file path", 0));
        browse->setText(QApplication::translate("DesktopPreferencesDialog", "&Browse", 0));
        groupBox_5->setTitle(QApplication::translate("DesktopPreferencesDialog", "Icons", 0));
        label_9->setText(QApplication::translate("DesktopPreferencesDialog", "Icon size:", 0));
        groupBox->setTitle(QApplication::translate("DesktopPreferencesDialog", "Label Text", 0));
        textColor->setText(QString());
        shadowColor->setText(QString());
        label_3->setText(QApplication::translate("DesktopPreferencesDialog", "Select  text color:", 0));
        label_4->setText(QApplication::translate("DesktopPreferencesDialog", "Select shadow color:", 0));
        label_2->setText(QApplication::translate("DesktopPreferencesDialog", "Select font:", 0));
        font->setText(QString());
        groupBox_3->setTitle(QApplication::translate("DesktopPreferencesDialog", "Spacing", 0));
        label_7->setText(QApplication::translate("DesktopPreferencesDialog", "Minimum item margins:", 0));
#ifndef QT_NO_TOOLTIP
        hMargin->setToolTip(QApplication::translate("DesktopPreferencesDialog", "3 px by default.", 0));
#endif // QT_NO_TOOLTIP
        hMargin->setSuffix(QApplication::translate("DesktopPreferencesDialog", " px", 0));
        label_8->setText(QApplication::translate("DesktopPreferencesDialog", "x", 0));
#ifndef QT_NO_TOOLTIP
        vMargin->setToolTip(QApplication::translate("DesktopPreferencesDialog", "1 px by default.\n"
"A space is also reserved for 3 lines of text.", 0));
#endif // QT_NO_TOOLTIP
        vMargin->setSuffix(QApplication::translate("DesktopPreferencesDialog", " px", 0));
        lockMargins->setText(QApplication::translate("DesktopPreferencesDialog", "Lock", 0));
        tabWidget->setTabText(tabWidget->indexOf(generalPage), QApplication::translate("DesktopPreferencesDialog", "General", 0));
        groupBox_4->setTitle(QApplication::translate("DesktopPreferencesDialog", "Window Manager", 0));
        showWmMenu->setText(QApplication::translate("DesktopPreferencesDialog", "Show menus provided by window managers when desktop is clicked", 0));
        tabWidget->setTabText(tabWidget->indexOf(advancedPage), QApplication::translate("DesktopPreferencesDialog", "Advanced", 0));
    } // retranslateUi

};

namespace Ui {
    class DesktopPreferencesDialog: public Ui_DesktopPreferencesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DESKTOP_2D_PREFERENCES_H
