/********************************************************************************
** Form generated from reading UI file 'main-win.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAIN_2D_WIN_H
#define UI_MAIN_2D_WIN_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <libfm-qt/sidepane.h>
#include "tabbar.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QAction *actionGoUp;
    QAction *actionHome;
    QAction *actionReload;
    QAction *actionGo;
    QAction *actionQuit;
    QAction *actionAbout;
    QAction *actionNewWin;
    QAction *actionShowHidden;
    QAction *actionComputer;
    QAction *actionTrash;
    QAction *actionNetwork;
    QAction *actionDesktop;
    QAction *actionAddToBookmarks;
    QAction *actionApplications;
    QAction *actionReload_2;
    QAction *actionIconView;
    QAction *actionCompactView;
    QAction *actionDetailedList;
    QAction *actionThumbnailView;
    QAction *actionCut;
    QAction *actionCopy;
    QAction *actionPaste;
    QAction *actionSelectAll;
    QAction *actionPreferences;
    QAction *actionAscending;
    QAction *actionDescending;
    QAction *actionByFileName;
    QAction *actionByMTime;
    QAction *actionByFileType;
    QAction *actionByOwner;
    QAction *actionFolderFirst;
    QAction *actionPreserveSorting;
    QAction *actionNewTab;
    QAction *actionGoBack;
    QAction *actionGoForward;
    QAction *actionInvertSelection;
    QAction *actionDelete;
    QAction *actionRename;
    QAction *actionCloseTab;
    QAction *actionFileProperties;
    QAction *actionFolderProperties;
    QAction *actionCaseSensitive;
    QAction *actionByFileSize;
    QAction *actionCloseWindow;
    QAction *actionEdit_Bookmarks;
    QAction *actionOpenTerminal;
    QAction *actionOpenAsRoot;
    QAction *actionEditBookmarks;
    QAction *actionNewFolder;
    QAction *actionNewBlankFile;
    QAction *actionFindFiles;
    QAction *actionFilter;
    QAction *actionCloseLeft;
    QAction *actionCloseRight;
    QAction *actionCloseOther;
    QAction *actionMenu_bar;
    QAction *actionMenu;
    QAction *actionPreserveView;
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout;
    PCManFM::TabBar *tabBar;
    QSplitter *splitter;
    Fm::SidePane *sidePane;
    QFrame *frame;
    QVBoxLayout *verticalLayout_2;
    QStackedWidget *stackedWidget;
    QLineEdit *filterBar;
    QMenuBar *menubar;
    QMenu *menu_File;
    QMenu *menuCreateNew;
    QMenu *menu_Help;
    QMenu *menu_View;
    QMenu *menuSorting;
    QMenu *menu_View_2;
    QMenu *menu_Editw;
    QMenu *menu_Bookmarks;
    QMenu *menu_Go;
    QMenu *menu_Tool;
    QStatusBar *statusbar;
    QToolBar *toolBar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName(QStringLiteral("MainWindow"));
        MainWindow->resize(460, 369);
        QIcon icon;
        QString iconThemeName = QStringLiteral("folder");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        MainWindow->setWindowIcon(icon);
        actionGoUp = new QAction(MainWindow);
        actionGoUp->setObjectName(QStringLiteral("actionGoUp"));
        QIcon icon1;
        iconThemeName = QStringLiteral("go-up");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionGoUp->setIcon(icon1);
        actionHome = new QAction(MainWindow);
        actionHome->setObjectName(QStringLiteral("actionHome"));
        QIcon icon2;
        iconThemeName = QStringLiteral("user-home");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionHome->setIcon(icon2);
        actionReload = new QAction(MainWindow);
        actionReload->setObjectName(QStringLiteral("actionReload"));
        QIcon icon3;
        iconThemeName = QStringLiteral("view-refresh");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionReload->setIcon(icon3);
        actionGo = new QAction(MainWindow);
        actionGo->setObjectName(QStringLiteral("actionGo"));
        QIcon icon4;
        iconThemeName = QStringLiteral("go-jump");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionGo->setIcon(icon4);
        actionQuit = new QAction(MainWindow);
        actionQuit->setObjectName(QStringLiteral("actionQuit"));
        QIcon icon5;
        iconThemeName = QStringLiteral("application-exit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionQuit->setIcon(icon5);
        actionAbout = new QAction(MainWindow);
        actionAbout->setObjectName(QStringLiteral("actionAbout"));
        QIcon icon6;
        iconThemeName = QStringLiteral("help-about");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon6 = QIcon::fromTheme(iconThemeName);
        } else {
            icon6.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionAbout->setIcon(icon6);
        actionNewWin = new QAction(MainWindow);
        actionNewWin->setObjectName(QStringLiteral("actionNewWin"));
        QIcon icon7;
        iconThemeName = QStringLiteral("window-new");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon7 = QIcon::fromTheme(iconThemeName);
        } else {
            icon7.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionNewWin->setIcon(icon7);
        actionShowHidden = new QAction(MainWindow);
        actionShowHidden->setObjectName(QStringLiteral("actionShowHidden"));
        actionShowHidden->setCheckable(true);
        actionComputer = new QAction(MainWindow);
        actionComputer->setObjectName(QStringLiteral("actionComputer"));
        QIcon icon8;
        iconThemeName = QStringLiteral("computer");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon8 = QIcon::fromTheme(iconThemeName);
        } else {
            icon8.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionComputer->setIcon(icon8);
        actionTrash = new QAction(MainWindow);
        actionTrash->setObjectName(QStringLiteral("actionTrash"));
        QIcon icon9;
        iconThemeName = QStringLiteral("user-trash");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon9 = QIcon::fromTheme(iconThemeName);
        } else {
            icon9.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionTrash->setIcon(icon9);
        actionNetwork = new QAction(MainWindow);
        actionNetwork->setObjectName(QStringLiteral("actionNetwork"));
        actionDesktop = new QAction(MainWindow);
        actionDesktop->setObjectName(QStringLiteral("actionDesktop"));
        QIcon icon10;
        iconThemeName = QStringLiteral("user-desktop");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon10 = QIcon::fromTheme(iconThemeName);
        } else {
            icon10.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionDesktop->setIcon(icon10);
        actionAddToBookmarks = new QAction(MainWindow);
        actionAddToBookmarks->setObjectName(QStringLiteral("actionAddToBookmarks"));
        QIcon icon11;
        iconThemeName = QStringLiteral("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon11 = QIcon::fromTheme(iconThemeName);
        } else {
            icon11.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionAddToBookmarks->setIcon(icon11);
        actionApplications = new QAction(MainWindow);
        actionApplications->setObjectName(QStringLiteral("actionApplications"));
        actionReload_2 = new QAction(MainWindow);
        actionReload_2->setObjectName(QStringLiteral("actionReload_2"));
        actionIconView = new QAction(MainWindow);
        actionIconView->setObjectName(QStringLiteral("actionIconView"));
        actionIconView->setCheckable(true);
        actionCompactView = new QAction(MainWindow);
        actionCompactView->setObjectName(QStringLiteral("actionCompactView"));
        actionCompactView->setCheckable(true);
        actionDetailedList = new QAction(MainWindow);
        actionDetailedList->setObjectName(QStringLiteral("actionDetailedList"));
        actionDetailedList->setCheckable(true);
        actionThumbnailView = new QAction(MainWindow);
        actionThumbnailView->setObjectName(QStringLiteral("actionThumbnailView"));
        actionThumbnailView->setCheckable(true);
        actionCut = new QAction(MainWindow);
        actionCut->setObjectName(QStringLiteral("actionCut"));
        QIcon icon12;
        iconThemeName = QStringLiteral("edit-cut");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon12 = QIcon::fromTheme(iconThemeName);
        } else {
            icon12.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionCut->setIcon(icon12);
        actionCopy = new QAction(MainWindow);
        actionCopy->setObjectName(QStringLiteral("actionCopy"));
        QIcon icon13;
        iconThemeName = QStringLiteral("edit-copy");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon13 = QIcon::fromTheme(iconThemeName);
        } else {
            icon13.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionCopy->setIcon(icon13);
        actionPaste = new QAction(MainWindow);
        actionPaste->setObjectName(QStringLiteral("actionPaste"));
        QIcon icon14;
        iconThemeName = QStringLiteral("edit-paste");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon14 = QIcon::fromTheme(iconThemeName);
        } else {
            icon14.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionPaste->setIcon(icon14);
        actionSelectAll = new QAction(MainWindow);
        actionSelectAll->setObjectName(QStringLiteral("actionSelectAll"));
        actionPreferences = new QAction(MainWindow);
        actionPreferences->setObjectName(QStringLiteral("actionPreferences"));
        actionAscending = new QAction(MainWindow);
        actionAscending->setObjectName(QStringLiteral("actionAscending"));
        actionAscending->setCheckable(true);
        actionDescending = new QAction(MainWindow);
        actionDescending->setObjectName(QStringLiteral("actionDescending"));
        actionDescending->setCheckable(true);
        actionByFileName = new QAction(MainWindow);
        actionByFileName->setObjectName(QStringLiteral("actionByFileName"));
        actionByFileName->setCheckable(true);
        actionByMTime = new QAction(MainWindow);
        actionByMTime->setObjectName(QStringLiteral("actionByMTime"));
        actionByMTime->setCheckable(true);
        actionByFileType = new QAction(MainWindow);
        actionByFileType->setObjectName(QStringLiteral("actionByFileType"));
        actionByFileType->setCheckable(true);
        actionByOwner = new QAction(MainWindow);
        actionByOwner->setObjectName(QStringLiteral("actionByOwner"));
        actionByOwner->setCheckable(true);
        actionFolderFirst = new QAction(MainWindow);
        actionFolderFirst->setObjectName(QStringLiteral("actionFolderFirst"));
        actionFolderFirst->setCheckable(true);
        actionPreserveSorting = new QAction(MainWindow);
        actionPreserveSorting->setObjectName(QStringLiteral("actionPreserveSorting"));
        actionPreserveSorting->setCheckable(true);
        actionNewTab = new QAction(MainWindow);
        actionNewTab->setObjectName(QStringLiteral("actionNewTab"));
        actionNewTab->setIcon(icon7);
        actionGoBack = new QAction(MainWindow);
        actionGoBack->setObjectName(QStringLiteral("actionGoBack"));
        QIcon icon15;
        iconThemeName = QStringLiteral("go-previous");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon15 = QIcon::fromTheme(iconThemeName);
        } else {
            icon15.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionGoBack->setIcon(icon15);
        actionGoForward = new QAction(MainWindow);
        actionGoForward->setObjectName(QStringLiteral("actionGoForward"));
        QIcon icon16;
        iconThemeName = QStringLiteral("go-next");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon16 = QIcon::fromTheme(iconThemeName);
        } else {
            icon16.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionGoForward->setIcon(icon16);
        actionInvertSelection = new QAction(MainWindow);
        actionInvertSelection->setObjectName(QStringLiteral("actionInvertSelection"));
        actionDelete = new QAction(MainWindow);
        actionDelete->setObjectName(QStringLiteral("actionDelete"));
        QIcon icon17;
        iconThemeName = QStringLiteral("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon17 = QIcon::fromTheme(iconThemeName);
        } else {
            icon17.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionDelete->setIcon(icon17);
        actionRename = new QAction(MainWindow);
        actionRename->setObjectName(QStringLiteral("actionRename"));
        actionCloseTab = new QAction(MainWindow);
        actionCloseTab->setObjectName(QStringLiteral("actionCloseTab"));
        actionFileProperties = new QAction(MainWindow);
        actionFileProperties->setObjectName(QStringLiteral("actionFileProperties"));
        actionFolderProperties = new QAction(MainWindow);
        actionFolderProperties->setObjectName(QStringLiteral("actionFolderProperties"));
        actionCaseSensitive = new QAction(MainWindow);
        actionCaseSensitive->setObjectName(QStringLiteral("actionCaseSensitive"));
        actionCaseSensitive->setCheckable(true);
        actionByFileSize = new QAction(MainWindow);
        actionByFileSize->setObjectName(QStringLiteral("actionByFileSize"));
        actionByFileSize->setCheckable(true);
        actionCloseWindow = new QAction(MainWindow);
        actionCloseWindow->setObjectName(QStringLiteral("actionCloseWindow"));
        actionEdit_Bookmarks = new QAction(MainWindow);
        actionEdit_Bookmarks->setObjectName(QStringLiteral("actionEdit_Bookmarks"));
        actionOpenTerminal = new QAction(MainWindow);
        actionOpenTerminal->setObjectName(QStringLiteral("actionOpenTerminal"));
        actionOpenAsRoot = new QAction(MainWindow);
        actionOpenAsRoot->setObjectName(QStringLiteral("actionOpenAsRoot"));
        actionEditBookmarks = new QAction(MainWindow);
        actionEditBookmarks->setObjectName(QStringLiteral("actionEditBookmarks"));
        actionNewFolder = new QAction(MainWindow);
        actionNewFolder->setObjectName(QStringLiteral("actionNewFolder"));
        QIcon icon18;
        iconThemeName = QStringLiteral("folder-new");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon18 = QIcon::fromTheme(iconThemeName);
        } else {
            icon18.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionNewFolder->setIcon(icon18);
        actionNewBlankFile = new QAction(MainWindow);
        actionNewBlankFile->setObjectName(QStringLiteral("actionNewBlankFile"));
        QIcon icon19;
        iconThemeName = QStringLiteral("document-new");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon19 = QIcon::fromTheme(iconThemeName);
        } else {
            icon19.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionNewBlankFile->setIcon(icon19);
        actionFindFiles = new QAction(MainWindow);
        actionFindFiles->setObjectName(QStringLiteral("actionFindFiles"));
        actionFilter = new QAction(MainWindow);
        actionFilter->setObjectName(QStringLiteral("actionFilter"));
        actionFilter->setCheckable(true);
        actionCloseLeft = new QAction(MainWindow);
        actionCloseLeft->setObjectName(QStringLiteral("actionCloseLeft"));
        actionCloseLeft->setIcon(icon15);
        actionCloseRight = new QAction(MainWindow);
        actionCloseRight->setObjectName(QStringLiteral("actionCloseRight"));
        actionCloseRight->setIcon(icon16);
        actionCloseOther = new QAction(MainWindow);
        actionCloseOther->setObjectName(QStringLiteral("actionCloseOther"));
        actionMenu_bar = new QAction(MainWindow);
        actionMenu_bar->setObjectName(QStringLiteral("actionMenu_bar"));
        actionMenu_bar->setCheckable(true);
        actionMenu = new QAction(MainWindow);
        actionMenu->setObjectName(QStringLiteral("actionMenu"));
        QIcon icon20;
        iconThemeName = QStringLiteral("application-menu");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon20 = QIcon::fromTheme(iconThemeName);
        } else {
            icon20.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        actionMenu->setIcon(icon20);
        actionPreserveView = new QAction(MainWindow);
        actionPreserveView->setObjectName(QStringLiteral("actionPreserveView"));
        actionPreserveView->setCheckable(true);
        centralwidget = new QWidget(MainWindow);
        centralwidget->setObjectName(QStringLiteral("centralwidget"));
        verticalLayout = new QVBoxLayout(centralwidget);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tabBar = new PCManFM::TabBar(centralwidget);
        tabBar->setObjectName(QStringLiteral("tabBar"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabBar->sizePolicy().hasHeightForWidth());
        tabBar->setSizePolicy(sizePolicy);
        tabBar->setAcceptDrops(true);

        verticalLayout->addWidget(tabBar);

        splitter = new QSplitter(centralwidget);
        splitter->setObjectName(QStringLiteral("splitter"));
        splitter->setOrientation(Qt::Horizontal);
        sidePane = new Fm::SidePane(splitter);
        sidePane->setObjectName(QStringLiteral("sidePane"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sidePane->sizePolicy().hasHeightForWidth());
        sidePane->setSizePolicy(sizePolicy1);
        splitter->addWidget(sidePane);
        frame = new QFrame(splitter);
        frame->setObjectName(QStringLiteral("frame"));
        verticalLayout_2 = new QVBoxLayout(frame);
        verticalLayout_2->setSpacing(2);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        verticalLayout_2->setContentsMargins(1, 0, 0, 0);
        stackedWidget = new QStackedWidget(frame);
        stackedWidget->setObjectName(QStringLiteral("stackedWidget"));
        QSizePolicy sizePolicy2(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(stackedWidget->sizePolicy().hasHeightForWidth());
        stackedWidget->setSizePolicy(sizePolicy2);

        verticalLayout_2->addWidget(stackedWidget);

        filterBar = new QLineEdit(frame);
        filterBar->setObjectName(QStringLiteral("filterBar"));
        filterBar->setClearButtonEnabled(true);

        verticalLayout_2->addWidget(filterBar);

        splitter->addWidget(frame);

        verticalLayout->addWidget(splitter);

        MainWindow->setCentralWidget(centralwidget);
        menubar = new QMenuBar(MainWindow);
        menubar->setObjectName(QStringLiteral("menubar"));
        menubar->setGeometry(QRect(0, 0, 460, 30));
        menu_File = new QMenu(menubar);
        menu_File->setObjectName(QStringLiteral("menu_File"));
        menuCreateNew = new QMenu(menu_File);
        menuCreateNew->setObjectName(QStringLiteral("menuCreateNew"));
        menu_Help = new QMenu(menubar);
        menu_Help->setObjectName(QStringLiteral("menu_Help"));
        menu_View = new QMenu(menubar);
        menu_View->setObjectName(QStringLiteral("menu_View"));
        menuSorting = new QMenu(menu_View);
        menuSorting->setObjectName(QStringLiteral("menuSorting"));
        menu_View_2 = new QMenu(menu_View);
        menu_View_2->setObjectName(QStringLiteral("menu_View_2"));
        menu_Editw = new QMenu(menubar);
        menu_Editw->setObjectName(QStringLiteral("menu_Editw"));
        menu_Bookmarks = new QMenu(menubar);
        menu_Bookmarks->setObjectName(QStringLiteral("menu_Bookmarks"));
        menu_Go = new QMenu(menubar);
        menu_Go->setObjectName(QStringLiteral("menu_Go"));
        menu_Tool = new QMenu(menubar);
        menu_Tool->setObjectName(QStringLiteral("menu_Tool"));
        MainWindow->setMenuBar(menubar);
        statusbar = new QStatusBar(MainWindow);
        statusbar->setObjectName(QStringLiteral("statusbar"));
        MainWindow->setStatusBar(statusbar);
        toolBar = new QToolBar(MainWindow);
        toolBar->setObjectName(QStringLiteral("toolBar"));
        toolBar->setMovable(false);
        toolBar->setFloatable(false);
        MainWindow->addToolBar(Qt::TopToolBarArea, toolBar);

        menubar->addAction(menu_File->menuAction());
        menubar->addAction(menu_Editw->menuAction());
        menubar->addAction(menu_View->menuAction());
        menubar->addAction(menu_Go->menuAction());
        menubar->addAction(menu_Bookmarks->menuAction());
        menubar->addAction(menu_Tool->menuAction());
        menubar->addAction(menu_Help->menuAction());
        menu_File->addAction(actionNewTab);
        menu_File->addAction(actionNewWin);
        menu_File->addSeparator();
        menu_File->addAction(menuCreateNew->menuAction());
        menu_File->addSeparator();
        menu_File->addAction(actionFileProperties);
        menu_File->addAction(actionFolderProperties);
        menu_File->addSeparator();
        menu_File->addAction(actionCloseTab);
        menu_File->addAction(actionCloseWindow);
        menuCreateNew->addAction(actionNewFolder);
        menuCreateNew->addAction(actionNewBlankFile);
        menu_Help->addAction(actionAbout);
        menu_View->addAction(actionReload);
        menu_View->addSeparator();
        menu_View->addAction(actionShowHidden);
        menu_View->addAction(menuSorting->menuAction());
        menu_View->addAction(menu_View_2->menuAction());
        menu_View->addAction(actionPreserveView);
        menu_View->addSeparator();
        menu_View->addAction(actionFilter);
        menu_View->addAction(actionMenu_bar);
        menuSorting->addAction(actionByFileName);
        menuSorting->addAction(actionByMTime);
        menuSorting->addAction(actionByFileSize);
        menuSorting->addAction(actionByFileType);
        menuSorting->addAction(actionByOwner);
        menuSorting->addSeparator();
        menuSorting->addAction(actionAscending);
        menuSorting->addAction(actionDescending);
        menuSorting->addSeparator();
        menuSorting->addAction(actionFolderFirst);
        menuSorting->addAction(actionCaseSensitive);
        menu_View_2->addAction(actionIconView);
        menu_View_2->addAction(actionThumbnailView);
        menu_View_2->addAction(actionCompactView);
        menu_View_2->addAction(actionDetailedList);
        menu_View_2->addSeparator();
        menu_Editw->addAction(actionCut);
        menu_Editw->addAction(actionCopy);
        menu_Editw->addAction(actionPaste);
        menu_Editw->addAction(actionRename);
        menu_Editw->addAction(actionDelete);
        menu_Editw->addSeparator();
        menu_Editw->addAction(actionSelectAll);
        menu_Editw->addAction(actionInvertSelection);
        menu_Editw->addSeparator();
        menu_Editw->addAction(actionPreferences);
        menu_Bookmarks->addAction(actionAddToBookmarks);
        menu_Bookmarks->addAction(actionEditBookmarks);
        menu_Go->addAction(actionHome);
        menu_Go->addAction(actionDesktop);
        menu_Go->addAction(actionComputer);
        menu_Go->addAction(actionTrash);
        menu_Go->addAction(actionNetwork);
        menu_Go->addAction(actionApplications);
        menu_Go->addSeparator();
        menu_Go->addAction(actionGoBack);
        menu_Go->addAction(actionGoForward);
        menu_Go->addAction(actionGoUp);
        menu_Tool->addAction(actionOpenTerminal);
        menu_Tool->addAction(actionOpenAsRoot);
        menu_Tool->addAction(actionFindFiles);
        toolBar->addAction(actionNewTab);
        toolBar->addAction(actionGoBack);
        toolBar->addAction(actionGoForward);
        toolBar->addAction(actionGoUp);
        toolBar->addAction(actionReload);
        toolBar->addAction(actionGo);
        toolBar->addSeparator();
        toolBar->addAction(actionMenu);

        retranslateUi(MainWindow);

        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QApplication::translate("MainWindow", "File Manager", 0));
        actionGoUp->setText(QApplication::translate("MainWindow", "Go &Up", 0));
#ifndef QT_NO_TOOLTIP
        actionGoUp->setToolTip(QApplication::translate("MainWindow", "Go Up", 0));
#endif // QT_NO_TOOLTIP
        actionGoUp->setShortcut(QApplication::translate("MainWindow", "Alt+Up", 0));
        actionHome->setText(QApplication::translate("MainWindow", "&Home", 0));
        actionHome->setShortcut(QApplication::translate("MainWindow", "Alt+Home", 0));
        actionReload->setText(QApplication::translate("MainWindow", "&Reload", 0));
        actionReload->setShortcut(QApplication::translate("MainWindow", "F5", 0));
        actionGo->setText(QApplication::translate("MainWindow", "Go", 0));
        actionQuit->setText(QApplication::translate("MainWindow", "Quit", 0));
        actionAbout->setText(QApplication::translate("MainWindow", "&About", 0));
        actionNewWin->setText(QApplication::translate("MainWindow", "&New Window", 0));
#ifndef QT_NO_TOOLTIP
        actionNewWin->setToolTip(QApplication::translate("MainWindow", "New Window", 0));
#endif // QT_NO_TOOLTIP
        actionNewWin->setShortcut(QApplication::translate("MainWindow", "Ctrl+N", 0));
        actionShowHidden->setText(QApplication::translate("MainWindow", "Show &Hidden", 0));
        actionShowHidden->setShortcut(QApplication::translate("MainWindow", "Ctrl+H", 0));
        actionComputer->setText(QApplication::translate("MainWindow", "&Computer", 0));
        actionTrash->setText(QApplication::translate("MainWindow", "&Trash", 0));
        actionNetwork->setText(QApplication::translate("MainWindow", "&Network", 0));
        actionDesktop->setText(QApplication::translate("MainWindow", "&Desktop", 0));
        actionAddToBookmarks->setText(QApplication::translate("MainWindow", "&Add to Bookmarks", 0));
        actionApplications->setText(QApplication::translate("MainWindow", "&Applications", 0));
        actionReload_2->setText(QApplication::translate("MainWindow", "Reload", 0));
        actionIconView->setText(QApplication::translate("MainWindow", "&Icon View", 0));
        actionCompactView->setText(QApplication::translate("MainWindow", "&Compact View", 0));
        actionDetailedList->setText(QApplication::translate("MainWindow", "&Detailed List", 0));
        actionThumbnailView->setText(QApplication::translate("MainWindow", "&Thumbnail View", 0));
        actionCut->setText(QApplication::translate("MainWindow", "Cu&t", 0));
        actionCut->setShortcut(QApplication::translate("MainWindow", "Ctrl+X", 0));
        actionCopy->setText(QApplication::translate("MainWindow", "&Copy", 0));
        actionCopy->setShortcut(QApplication::translate("MainWindow", "Ctrl+C", 0));
        actionPaste->setText(QApplication::translate("MainWindow", "&Paste", 0));
        actionPaste->setShortcut(QApplication::translate("MainWindow", "Ctrl+V", 0));
        actionSelectAll->setText(QApplication::translate("MainWindow", "Select &All", 0));
        actionSelectAll->setShortcut(QApplication::translate("MainWindow", "Ctrl+A", 0));
        actionPreferences->setText(QApplication::translate("MainWindow", "Pr&eferences", 0));
        actionAscending->setText(QApplication::translate("MainWindow", "&Ascending", 0));
        actionDescending->setText(QApplication::translate("MainWindow", "&Descending", 0));
        actionByFileName->setText(QApplication::translate("MainWindow", "&By File Name", 0));
        actionByMTime->setText(QApplication::translate("MainWindow", "By &Modification Time", 0));
        actionByFileType->setText(QApplication::translate("MainWindow", "By File &Type", 0));
        actionByOwner->setText(QApplication::translate("MainWindow", "By &Owner", 0));
        actionFolderFirst->setText(QApplication::translate("MainWindow", "&Folder First", 0));
        actionPreserveSorting->setText(QApplication::translate("MainWindow", "&Preserve sorting for this folder", 0));
        actionNewTab->setText(QApplication::translate("MainWindow", "New &Tab", 0));
#ifndef QT_NO_TOOLTIP
        actionNewTab->setToolTip(QApplication::translate("MainWindow", "New Tab", 0));
#endif // QT_NO_TOOLTIP
        actionNewTab->setShortcut(QApplication::translate("MainWindow", "Ctrl+T", 0));
        actionGoBack->setText(QApplication::translate("MainWindow", "Go &Back", 0));
#ifndef QT_NO_TOOLTIP
        actionGoBack->setToolTip(QApplication::translate("MainWindow", "Go Back", 0));
#endif // QT_NO_TOOLTIP
        actionGoBack->setShortcut(QApplication::translate("MainWindow", "Alt+Left", 0));
        actionGoForward->setText(QApplication::translate("MainWindow", "Go &Forward", 0));
#ifndef QT_NO_TOOLTIP
        actionGoForward->setToolTip(QApplication::translate("MainWindow", "Go Forward", 0));
#endif // QT_NO_TOOLTIP
        actionGoForward->setShortcut(QApplication::translate("MainWindow", "Alt+Right", 0));
        actionInvertSelection->setText(QApplication::translate("MainWindow", "&Invert Selection", 0));
        actionDelete->setText(QApplication::translate("MainWindow", "&Delete", 0));
        actionDelete->setShortcut(QApplication::translate("MainWindow", "Del", 0));
        actionRename->setText(QApplication::translate("MainWindow", "&Rename", 0));
        actionRename->setShortcut(QApplication::translate("MainWindow", "F2", 0));
        actionCloseTab->setText(QApplication::translate("MainWindow", "C&lose Tab", 0));
        actionCloseTab->setShortcut(QApplication::translate("MainWindow", "Ctrl+W", 0));
        actionFileProperties->setText(QApplication::translate("MainWindow", "File &Properties", 0));
        actionFileProperties->setShortcut(QApplication::translate("MainWindow", "Alt+Return", 0));
        actionFolderProperties->setText(QApplication::translate("MainWindow", "&Folder Properties", 0));
        actionCaseSensitive->setText(QApplication::translate("MainWindow", "&Case Sensitive", 0));
        actionByFileSize->setText(QApplication::translate("MainWindow", "By File &Size", 0));
        actionCloseWindow->setText(QApplication::translate("MainWindow", "&Close Window", 0));
        actionCloseWindow->setShortcut(QApplication::translate("MainWindow", "Ctrl+Q", 0));
        actionEdit_Bookmarks->setText(QApplication::translate("MainWindow", "Edit Bookmarks", 0));
        actionOpenTerminal->setText(QApplication::translate("MainWindow", "Open &Terminal", 0));
        actionOpenTerminal->setShortcut(QApplication::translate("MainWindow", "F4", 0));
        actionOpenAsRoot->setText(QApplication::translate("MainWindow", "Open as &Root", 0));
        actionEditBookmarks->setText(QApplication::translate("MainWindow", "&Edit Bookmarks", 0));
        actionNewFolder->setText(QApplication::translate("MainWindow", "&Folder", 0));
        actionNewFolder->setShortcut(QApplication::translate("MainWindow", "Ctrl+Shift+N", 0));
        actionNewBlankFile->setText(QApplication::translate("MainWindow", "&Blank File", 0));
        actionNewBlankFile->setShortcut(QApplication::translate("MainWindow", "Ctrl+Alt+N", 0));
        actionFindFiles->setText(QApplication::translate("MainWindow", "&Find Files", 0));
        actionFindFiles->setShortcut(QApplication::translate("MainWindow", "F3", 0));
        actionFilter->setText(QApplication::translate("MainWindow", "&Filter", 0));
        actionFilter->setShortcut(QApplication::translate("MainWindow", "Ctrl+B", 0));
        actionCloseLeft->setText(QApplication::translate("MainWindow", "Close &previous tabs", 0));
        actionCloseRight->setText(QApplication::translate("MainWindow", "Close &next tabs", 0));
        actionCloseOther->setText(QApplication::translate("MainWindow", "Close &other tabs", 0));
        actionMenu_bar->setText(QApplication::translate("MainWindow", "Menu bar", 0));
#ifndef QT_NO_TOOLTIP
        actionMenu_bar->setToolTip(QApplication::translate("MainWindow", "Menu bar", 0));
#endif // QT_NO_TOOLTIP
        actionMenu_bar->setShortcut(QApplication::translate("MainWindow", "Ctrl+M", 0));
        actionMenu->setText(QApplication::translate("MainWindow", "Menu", 0));
#ifndef QT_NO_TOOLTIP
        actionMenu->setToolTip(QApplication::translate("MainWindow", "Menu", 0));
#endif // QT_NO_TOOLTIP
        actionPreserveView->setText(QApplication::translate("MainWindow", "&Preserve Settings for This Folder", 0));
#ifndef QT_NO_TOOLTIP
        filterBar->setToolTip(QApplication::translate("MainWindow", "Focus with Ctrl+I", 0));
#endif // QT_NO_TOOLTIP
        filterBar->setPlaceholderText(QApplication::translate("MainWindow", "Filter by string...", 0));
        menu_File->setTitle(QApplication::translate("MainWindow", "&File", 0));
        menuCreateNew->setTitle(QApplication::translate("MainWindow", "C&reate New", 0));
        menu_Help->setTitle(QApplication::translate("MainWindow", "&Help", 0));
        menu_View->setTitle(QApplication::translate("MainWindow", "&View", 0));
        menuSorting->setTitle(QApplication::translate("MainWindow", "&Sorting", 0));
        menu_View_2->setTitle(QApplication::translate("MainWindow", "&View", 0));
        menu_Editw->setTitle(QApplication::translate("MainWindow", "&Edit", 0));
        menu_Bookmarks->setTitle(QApplication::translate("MainWindow", "&Bookmarks", 0));
        menu_Go->setTitle(QApplication::translate("MainWindow", "&Go", 0));
        menu_Tool->setTitle(QApplication::translate("MainWindow", "&Tool", 0));
        toolBar->setWindowTitle(QApplication::translate("MainWindow", "Main Toolbar", 0));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAIN_2D_WIN_H
