/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/pcmanfm-qt-0.11.1/pcmanfm/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_PCManFM__MainWindow_t {
    QByteArrayData data[98];
    char stringdata0[2236];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PCManFM__MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PCManFM__MainWindow_t qt_meta_stringdata_PCManFM__MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 19), // "PCManFM::MainWindow"
QT_MOC_LITERAL(1, 20, 24), // "onPathEntryReturnPressed"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 17), // "onPathEntryEdited"
QT_MOC_LITERAL(4, 64, 4), // "text"
QT_MOC_LITERAL(5, 69, 25), // "on_actionNewTab_triggered"
QT_MOC_LITERAL(6, 95, 25), // "on_actionNewWin_triggered"
QT_MOC_LITERAL(7, 121, 28), // "on_actionNewFolder_triggered"
QT_MOC_LITERAL(8, 150, 31), // "on_actionNewBlankFile_triggered"
QT_MOC_LITERAL(9, 182, 27), // "on_actionCloseTab_triggered"
QT_MOC_LITERAL(10, 210, 30), // "on_actionCloseWindow_triggered"
QT_MOC_LITERAL(11, 241, 33), // "on_actionFileProperties_trigg..."
QT_MOC_LITERAL(12, 275, 35), // "on_actionFolderProperties_tri..."
QT_MOC_LITERAL(13, 311, 22), // "on_actionCut_triggered"
QT_MOC_LITERAL(14, 334, 23), // "on_actionCopy_triggered"
QT_MOC_LITERAL(15, 358, 24), // "on_actionPaste_triggered"
QT_MOC_LITERAL(16, 383, 25), // "on_actionDelete_triggered"
QT_MOC_LITERAL(17, 409, 25), // "on_actionRename_triggered"
QT_MOC_LITERAL(18, 435, 28), // "on_actionSelectAll_triggered"
QT_MOC_LITERAL(19, 464, 34), // "on_actionInvertSelection_trig..."
QT_MOC_LITERAL(20, 499, 30), // "on_actionPreferences_triggered"
QT_MOC_LITERAL(21, 530, 25), // "on_actionGoBack_triggered"
QT_MOC_LITERAL(22, 556, 28), // "on_actionGoForward_triggered"
QT_MOC_LITERAL(23, 585, 23), // "on_actionGoUp_triggered"
QT_MOC_LITERAL(24, 609, 23), // "on_actionHome_triggered"
QT_MOC_LITERAL(25, 633, 25), // "on_actionReload_triggered"
QT_MOC_LITERAL(26, 659, 27), // "on_actionIconView_triggered"
QT_MOC_LITERAL(27, 687, 30), // "on_actionCompactView_triggered"
QT_MOC_LITERAL(28, 718, 31), // "on_actionDetailedList_triggered"
QT_MOC_LITERAL(29, 750, 32), // "on_actionThumbnailView_triggered"
QT_MOC_LITERAL(30, 783, 21), // "on_actionGo_triggered"
QT_MOC_LITERAL(31, 805, 29), // "on_actionShowHidden_triggered"
QT_MOC_LITERAL(32, 835, 5), // "check"
QT_MOC_LITERAL(33, 841, 31), // "on_actionPreserveView_triggered"
QT_MOC_LITERAL(34, 873, 7), // "checked"
QT_MOC_LITERAL(35, 881, 29), // "on_actionByFileName_triggered"
QT_MOC_LITERAL(36, 911, 26), // "on_actionByMTime_triggered"
QT_MOC_LITERAL(37, 938, 26), // "on_actionByOwner_triggered"
QT_MOC_LITERAL(38, 965, 29), // "on_actionByFileType_triggered"
QT_MOC_LITERAL(39, 995, 29), // "on_actionByFileSize_triggered"
QT_MOC_LITERAL(40, 1025, 28), // "on_actionAscending_triggered"
QT_MOC_LITERAL(41, 1054, 29), // "on_actionDescending_triggered"
QT_MOC_LITERAL(42, 1084, 30), // "on_actionFolderFirst_triggered"
QT_MOC_LITERAL(43, 1115, 32), // "on_actionCaseSensitive_triggered"
QT_MOC_LITERAL(44, 1148, 25), // "on_actionFilter_triggered"
QT_MOC_LITERAL(45, 1174, 31), // "on_actionApplications_triggered"
QT_MOC_LITERAL(46, 1206, 27), // "on_actionComputer_triggered"
QT_MOC_LITERAL(47, 1234, 24), // "on_actionTrash_triggered"
QT_MOC_LITERAL(48, 1259, 26), // "on_actionNetwork_triggered"
QT_MOC_LITERAL(49, 1286, 26), // "on_actionDesktop_triggered"
QT_MOC_LITERAL(50, 1313, 33), // "on_actionAddToBookmarks_trigg..."
QT_MOC_LITERAL(51, 1347, 32), // "on_actionEditBookmarks_triggered"
QT_MOC_LITERAL(52, 1380, 31), // "on_actionOpenTerminal_triggered"
QT_MOC_LITERAL(53, 1412, 29), // "on_actionOpenAsRoot_triggered"
QT_MOC_LITERAL(54, 1442, 28), // "on_actionFindFiles_triggered"
QT_MOC_LITERAL(55, 1471, 24), // "on_actionAbout_triggered"
QT_MOC_LITERAL(56, 1496, 25), // "onBookmarkActionTriggered"
QT_MOC_LITERAL(57, 1522, 22), // "onTabBarCloseRequested"
QT_MOC_LITERAL(58, 1545, 5), // "index"
QT_MOC_LITERAL(59, 1551, 22), // "onTabBarCurrentChanged"
QT_MOC_LITERAL(60, 1574, 16), // "onTabBarTabMoved"
QT_MOC_LITERAL(61, 1591, 4), // "from"
QT_MOC_LITERAL(62, 1596, 2), // "to"
QT_MOC_LITERAL(63, 1599, 14), // "focusFilterBar"
QT_MOC_LITERAL(64, 1614, 21), // "onFilterStringChanged"
QT_MOC_LITERAL(65, 1636, 3), // "str"
QT_MOC_LITERAL(66, 1640, 17), // "onShortcutPrevTab"
QT_MOC_LITERAL(67, 1658, 17), // "onShortcutNextTab"
QT_MOC_LITERAL(68, 1676, 19), // "onShortcutJumpToTab"
QT_MOC_LITERAL(69, 1696, 28), // "onStackedWidgetWidgetRemoved"
QT_MOC_LITERAL(70, 1725, 21), // "onTabPageTitleChanged"
QT_MOC_LITERAL(71, 1747, 5), // "title"
QT_MOC_LITERAL(72, 1753, 22), // "onTabPageStatusChanged"
QT_MOC_LITERAL(73, 1776, 4), // "type"
QT_MOC_LITERAL(74, 1781, 10), // "statusText"
QT_MOC_LITERAL(75, 1792, 25), // "onTabPageOpenDirRequested"
QT_MOC_LITERAL(76, 1818, 7), // "FmPath*"
QT_MOC_LITERAL(77, 1826, 4), // "path"
QT_MOC_LITERAL(78, 1831, 6), // "target"
QT_MOC_LITERAL(79, 1838, 26), // "onTabPageSortFilterChanged"
QT_MOC_LITERAL(80, 1865, 24), // "onSidePaneChdirRequested"
QT_MOC_LITERAL(81, 1890, 40), // "onSidePaneOpenFolderInNewWind..."
QT_MOC_LITERAL(82, 1931, 37), // "onSidePaneOpenFolderInNewTabR..."
QT_MOC_LITERAL(83, 1969, 39), // "onSidePaneOpenFolderInTermina..."
QT_MOC_LITERAL(84, 2009, 34), // "onSidePaneCreateNewFolderRequ..."
QT_MOC_LITERAL(85, 2044, 21), // "onSidePaneModeChanged"
QT_MOC_LITERAL(86, 2066, 18), // "Fm::SidePane::Mode"
QT_MOC_LITERAL(87, 2085, 4), // "mode"
QT_MOC_LITERAL(88, 2090, 15), // "onSplitterMoved"
QT_MOC_LITERAL(89, 2106, 3), // "pos"
QT_MOC_LITERAL(90, 2110, 12), // "onResetFocus"
QT_MOC_LITERAL(91, 2123, 24), // "onBackForwardContextMenu"
QT_MOC_LITERAL(92, 2148, 14), // "tabContextMenu"
QT_MOC_LITERAL(93, 2163, 13), // "closeLeftTabs"
QT_MOC_LITERAL(94, 2177, 14), // "closeRightTabs"
QT_MOC_LITERAL(95, 2192, 14), // "closeOtherTabs"
QT_MOC_LITERAL(96, 2207, 14), // "focusPathEntry"
QT_MOC_LITERAL(97, 2222, 13) // "toggleMenuBar"

    },
    "PCManFM::MainWindow\0onPathEntryReturnPressed\0"
    "\0onPathEntryEdited\0text\0"
    "on_actionNewTab_triggered\0"
    "on_actionNewWin_triggered\0"
    "on_actionNewFolder_triggered\0"
    "on_actionNewBlankFile_triggered\0"
    "on_actionCloseTab_triggered\0"
    "on_actionCloseWindow_triggered\0"
    "on_actionFileProperties_triggered\0"
    "on_actionFolderProperties_triggered\0"
    "on_actionCut_triggered\0on_actionCopy_triggered\0"
    "on_actionPaste_triggered\0"
    "on_actionDelete_triggered\0"
    "on_actionRename_triggered\0"
    "on_actionSelectAll_triggered\0"
    "on_actionInvertSelection_triggered\0"
    "on_actionPreferences_triggered\0"
    "on_actionGoBack_triggered\0"
    "on_actionGoForward_triggered\0"
    "on_actionGoUp_triggered\0on_actionHome_triggered\0"
    "on_actionReload_triggered\0"
    "on_actionIconView_triggered\0"
    "on_actionCompactView_triggered\0"
    "on_actionDetailedList_triggered\0"
    "on_actionThumbnailView_triggered\0"
    "on_actionGo_triggered\0"
    "on_actionShowHidden_triggered\0check\0"
    "on_actionPreserveView_triggered\0checked\0"
    "on_actionByFileName_triggered\0"
    "on_actionByMTime_triggered\0"
    "on_actionByOwner_triggered\0"
    "on_actionByFileType_triggered\0"
    "on_actionByFileSize_triggered\0"
    "on_actionAscending_triggered\0"
    "on_actionDescending_triggered\0"
    "on_actionFolderFirst_triggered\0"
    "on_actionCaseSensitive_triggered\0"
    "on_actionFilter_triggered\0"
    "on_actionApplications_triggered\0"
    "on_actionComputer_triggered\0"
    "on_actionTrash_triggered\0"
    "on_actionNetwork_triggered\0"
    "on_actionDesktop_triggered\0"
    "on_actionAddToBookmarks_triggered\0"
    "on_actionEditBookmarks_triggered\0"
    "on_actionOpenTerminal_triggered\0"
    "on_actionOpenAsRoot_triggered\0"
    "on_actionFindFiles_triggered\0"
    "on_actionAbout_triggered\0"
    "onBookmarkActionTriggered\0"
    "onTabBarCloseRequested\0index\0"
    "onTabBarCurrentChanged\0onTabBarTabMoved\0"
    "from\0to\0focusFilterBar\0onFilterStringChanged\0"
    "str\0onShortcutPrevTab\0onShortcutNextTab\0"
    "onShortcutJumpToTab\0onStackedWidgetWidgetRemoved\0"
    "onTabPageTitleChanged\0title\0"
    "onTabPageStatusChanged\0type\0statusText\0"
    "onTabPageOpenDirRequested\0FmPath*\0"
    "path\0target\0onTabPageSortFilterChanged\0"
    "onSidePaneChdirRequested\0"
    "onSidePaneOpenFolderInNewWindowRequested\0"
    "onSidePaneOpenFolderInNewTabRequested\0"
    "onSidePaneOpenFolderInTerminalRequested\0"
    "onSidePaneCreateNewFolderRequested\0"
    "onSidePaneModeChanged\0Fm::SidePane::Mode\0"
    "mode\0onSplitterMoved\0pos\0onResetFocus\0"
    "onBackForwardContextMenu\0tabContextMenu\0"
    "closeLeftTabs\0closeRightTabs\0"
    "closeOtherTabs\0focusPathEntry\0"
    "toggleMenuBar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PCManFM__MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      80,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  414,    2, 0x09 /* Protected */,
       3,    1,  415,    2, 0x09 /* Protected */,
       5,    0,  418,    2, 0x09 /* Protected */,
       6,    0,  419,    2, 0x09 /* Protected */,
       7,    0,  420,    2, 0x09 /* Protected */,
       8,    0,  421,    2, 0x09 /* Protected */,
       9,    0,  422,    2, 0x09 /* Protected */,
      10,    0,  423,    2, 0x09 /* Protected */,
      11,    0,  424,    2, 0x09 /* Protected */,
      12,    0,  425,    2, 0x09 /* Protected */,
      13,    0,  426,    2, 0x09 /* Protected */,
      14,    0,  427,    2, 0x09 /* Protected */,
      15,    0,  428,    2, 0x09 /* Protected */,
      16,    0,  429,    2, 0x09 /* Protected */,
      17,    0,  430,    2, 0x09 /* Protected */,
      18,    0,  431,    2, 0x09 /* Protected */,
      19,    0,  432,    2, 0x09 /* Protected */,
      20,    0,  433,    2, 0x09 /* Protected */,
      21,    0,  434,    2, 0x09 /* Protected */,
      22,    0,  435,    2, 0x09 /* Protected */,
      23,    0,  436,    2, 0x09 /* Protected */,
      24,    0,  437,    2, 0x09 /* Protected */,
      25,    0,  438,    2, 0x09 /* Protected */,
      26,    0,  439,    2, 0x09 /* Protected */,
      27,    0,  440,    2, 0x09 /* Protected */,
      28,    0,  441,    2, 0x09 /* Protected */,
      29,    0,  442,    2, 0x09 /* Protected */,
      30,    0,  443,    2, 0x09 /* Protected */,
      31,    1,  444,    2, 0x09 /* Protected */,
      33,    1,  447,    2, 0x09 /* Protected */,
      35,    1,  450,    2, 0x09 /* Protected */,
      36,    1,  453,    2, 0x09 /* Protected */,
      37,    1,  456,    2, 0x09 /* Protected */,
      38,    1,  459,    2, 0x09 /* Protected */,
      39,    1,  462,    2, 0x09 /* Protected */,
      40,    1,  465,    2, 0x09 /* Protected */,
      41,    1,  468,    2, 0x09 /* Protected */,
      42,    1,  471,    2, 0x09 /* Protected */,
      43,    1,  474,    2, 0x09 /* Protected */,
      44,    1,  477,    2, 0x09 /* Protected */,
      45,    0,  480,    2, 0x09 /* Protected */,
      46,    0,  481,    2, 0x09 /* Protected */,
      47,    0,  482,    2, 0x09 /* Protected */,
      48,    0,  483,    2, 0x09 /* Protected */,
      49,    0,  484,    2, 0x09 /* Protected */,
      50,    0,  485,    2, 0x09 /* Protected */,
      51,    0,  486,    2, 0x09 /* Protected */,
      52,    0,  487,    2, 0x09 /* Protected */,
      53,    0,  488,    2, 0x09 /* Protected */,
      54,    0,  489,    2, 0x09 /* Protected */,
      55,    0,  490,    2, 0x09 /* Protected */,
      56,    0,  491,    2, 0x09 /* Protected */,
      57,    1,  492,    2, 0x09 /* Protected */,
      59,    1,  495,    2, 0x09 /* Protected */,
      60,    2,  498,    2, 0x09 /* Protected */,
      63,    0,  503,    2, 0x09 /* Protected */,
      64,    1,  504,    2, 0x09 /* Protected */,
      66,    0,  507,    2, 0x09 /* Protected */,
      67,    0,  508,    2, 0x09 /* Protected */,
      68,    0,  509,    2, 0x09 /* Protected */,
      69,    1,  510,    2, 0x09 /* Protected */,
      70,    1,  513,    2, 0x09 /* Protected */,
      72,    2,  516,    2, 0x09 /* Protected */,
      75,    2,  521,    2, 0x09 /* Protected */,
      79,    0,  526,    2, 0x09 /* Protected */,
      80,    2,  527,    2, 0x09 /* Protected */,
      81,    1,  532,    2, 0x09 /* Protected */,
      82,    1,  535,    2, 0x09 /* Protected */,
      83,    1,  538,    2, 0x09 /* Protected */,
      84,    1,  541,    2, 0x09 /* Protected */,
      85,    1,  544,    2, 0x09 /* Protected */,
      88,    2,  547,    2, 0x09 /* Protected */,
      90,    0,  552,    2, 0x09 /* Protected */,
      91,    1,  553,    2, 0x09 /* Protected */,
      92,    1,  556,    2, 0x09 /* Protected */,
      93,    0,  559,    2, 0x09 /* Protected */,
      94,    0,  560,    2, 0x09 /* Protected */,
      95,    0,  561,    2, 0x09 /* Protected */,
      96,    0,  562,    2, 0x09 /* Protected */,
      97,    1,  563,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   32,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   58,
    QMetaType::Void, QMetaType::Int,   58,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   61,   62,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   65,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   58,
    QMetaType::Void, QMetaType::QString,   71,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   73,   74,
    QMetaType::Void, 0x80000000 | 76, QMetaType::Int,   77,   78,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 76,   73,   77,
    QMetaType::Void, 0x80000000 | 76,   77,
    QMetaType::Void, 0x80000000 | 76,   77,
    QMetaType::Void, 0x80000000 | 76,   77,
    QMetaType::Void, 0x80000000 | 76,   77,
    QMetaType::Void, 0x80000000 | 86,   87,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   89,   58,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   89,
    QMetaType::Void, QMetaType::QPoint,   89,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   34,

       0        // eod
};

void PCManFM::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onPathEntryReturnPressed(); break;
        case 1: _t->onPathEntryEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->on_actionNewTab_triggered(); break;
        case 3: _t->on_actionNewWin_triggered(); break;
        case 4: _t->on_actionNewFolder_triggered(); break;
        case 5: _t->on_actionNewBlankFile_triggered(); break;
        case 6: _t->on_actionCloseTab_triggered(); break;
        case 7: _t->on_actionCloseWindow_triggered(); break;
        case 8: _t->on_actionFileProperties_triggered(); break;
        case 9: _t->on_actionFolderProperties_triggered(); break;
        case 10: _t->on_actionCut_triggered(); break;
        case 11: _t->on_actionCopy_triggered(); break;
        case 12: _t->on_actionPaste_triggered(); break;
        case 13: _t->on_actionDelete_triggered(); break;
        case 14: _t->on_actionRename_triggered(); break;
        case 15: _t->on_actionSelectAll_triggered(); break;
        case 16: _t->on_actionInvertSelection_triggered(); break;
        case 17: _t->on_actionPreferences_triggered(); break;
        case 18: _t->on_actionGoBack_triggered(); break;
        case 19: _t->on_actionGoForward_triggered(); break;
        case 20: _t->on_actionGoUp_triggered(); break;
        case 21: _t->on_actionHome_triggered(); break;
        case 22: _t->on_actionReload_triggered(); break;
        case 23: _t->on_actionIconView_triggered(); break;
        case 24: _t->on_actionCompactView_triggered(); break;
        case 25: _t->on_actionDetailedList_triggered(); break;
        case 26: _t->on_actionThumbnailView_triggered(); break;
        case 27: _t->on_actionGo_triggered(); break;
        case 28: _t->on_actionShowHidden_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->on_actionPreserveView_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->on_actionByFileName_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->on_actionByMTime_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->on_actionByOwner_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->on_actionByFileType_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 34: _t->on_actionByFileSize_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 35: _t->on_actionAscending_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 36: _t->on_actionDescending_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 37: _t->on_actionFolderFirst_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 38: _t->on_actionCaseSensitive_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->on_actionFilter_triggered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 40: _t->on_actionApplications_triggered(); break;
        case 41: _t->on_actionComputer_triggered(); break;
        case 42: _t->on_actionTrash_triggered(); break;
        case 43: _t->on_actionNetwork_triggered(); break;
        case 44: _t->on_actionDesktop_triggered(); break;
        case 45: _t->on_actionAddToBookmarks_triggered(); break;
        case 46: _t->on_actionEditBookmarks_triggered(); break;
        case 47: _t->on_actionOpenTerminal_triggered(); break;
        case 48: _t->on_actionOpenAsRoot_triggered(); break;
        case 49: _t->on_actionFindFiles_triggered(); break;
        case 50: _t->on_actionAbout_triggered(); break;
        case 51: _t->onBookmarkActionTriggered(); break;
        case 52: _t->onTabBarCloseRequested((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 53: _t->onTabBarCurrentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 54: _t->onTabBarTabMoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 55: _t->focusFilterBar(); break;
        case 56: _t->onFilterStringChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 57: _t->onShortcutPrevTab(); break;
        case 58: _t->onShortcutNextTab(); break;
        case 59: _t->onShortcutJumpToTab(); break;
        case 60: _t->onStackedWidgetWidgetRemoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 61: _t->onTabPageTitleChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 62: _t->onTabPageStatusChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 63: _t->onTabPageOpenDirRequested((*reinterpret_cast< FmPath*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 64: _t->onTabPageSortFilterChanged(); break;
        case 65: _t->onSidePaneChdirRequested((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< FmPath*(*)>(_a[2]))); break;
        case 66: _t->onSidePaneOpenFolderInNewWindowRequested((*reinterpret_cast< FmPath*(*)>(_a[1]))); break;
        case 67: _t->onSidePaneOpenFolderInNewTabRequested((*reinterpret_cast< FmPath*(*)>(_a[1]))); break;
        case 68: _t->onSidePaneOpenFolderInTerminalRequested((*reinterpret_cast< FmPath*(*)>(_a[1]))); break;
        case 69: _t->onSidePaneCreateNewFolderRequested((*reinterpret_cast< FmPath*(*)>(_a[1]))); break;
        case 70: _t->onSidePaneModeChanged((*reinterpret_cast< Fm::SidePane::Mode(*)>(_a[1]))); break;
        case 71: _t->onSplitterMoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 72: _t->onResetFocus(); break;
        case 73: _t->onBackForwardContextMenu((*reinterpret_cast< QPoint(*)>(_a[1]))); break;
        case 74: _t->tabContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 75: _t->closeLeftTabs(); break;
        case 76: _t->closeRightTabs(); break;
        case 77: _t->closeOtherTabs(); break;
        case 78: _t->focusPathEntry(); break;
        case 79: _t->toggleMenuBar((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject PCManFM::MainWindow::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_PCManFM__MainWindow.data,
      qt_meta_data_PCManFM__MainWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *PCManFM::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_PCManFM__MainWindow.stringdata0))
        return static_cast<void*>(const_cast< MainWindow*>(this));
    return QMainWindow::qt_metacast(_clname);
}

int PCManFM::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 80)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 80;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 80)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 80;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
